Package: partsm
Version: 1.1-5
Date: 2026-05-04
Title: Periodic Autoregressive Time Series Models
Authors@R: 
    c(person(given = "Javier",
             family = "Lopez-de-Lacalle",
             role = c("aut", "cph"),
             email = "javlacalle@yahoo.es"),
      person(given = "Matthieu",
             family = "Stigler",
             role = "cre",
             email = "Matthieu.Stigler@gmail.com",
             comment = c(ORCID = "0000-0002-6802-4290")))
Imports: methods
Depends: R (>= 2.14.0)
Description: Basic functions to fit and predict periodic autoregressive time series models. These models are discussed in the book P.H. Franses (1996) "Periodicity and Stochastic Trends in Economic Time Series", Oxford University Press. Data set analyzed in that book is also provided. NOTE: the package was orphaned during several years. It is now only maintained, but no major enhancements are expected, and the maintainer cannot provide any support. 
License: GPL-2
URL: https://github.com/MatthieuStigler/partsm
NeedsCompilation: no
Packaged: 2026-05-04 11:34:23 UTC; matifou
Author: Javier Lopez-de-Lacalle [aut, cph],
  Matthieu Stigler [cre] (ORCID: <https://orcid.org/0000-0002-6802-4290>)
Maintainer: Matthieu Stigler <Matthieu.Stigler@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-04 13:00:02 UTC
Built: R 4.5.2; ; 2026-05-04 16:58:32 UTC; unix

importFrom(methods, setClass, setMethod)
importFrom("graphics", "layout", "par", "text", "plot")
importFrom("methods", "new", "show")
importFrom("stats", "acf", "as.formula", "coef", "cycle", "end",
             "frequency", "lm", "monthplot", "na.exclude", "na.omit",
             "nls", "pf", "pnorm", "printCoefmat", "residuals", "sd",
             "start", "time", "ts", "ts.plot", "update")
             
export(acf.ext1, fit.ar.par, fit.piar, Fnextp.test, Fpar.test, Fpari.piar.test, Fsh.test,
       LRurpar.test, plotpdiff, plotpredpiar, predictpiar)

exportClasses("fit.partsm", "fit.piartsm", "Ftest.partsm", "LRur.partsm", "MVPAR",
              "MVPIAR", "pred.piartsm")

exportMethods("show", "summary", "PAR.MVrepr")

## Run from the repo root: ~/gitReps/my_github/partsm/

## 1. Compile vignette manually (Sweave + pdflatex, PDF written next to .Rnw)
##    No pre-built PDF committed -- CRAN rebuilds from .Rnw source directly
tools::buildVignette("vignettes/partsm.Rnw", dir = "vignettes/")
tools::compactPDF("vignettes/partsm.pdf", gs_quality = "ebook")

## 2. Build the source tarball (compacts vignettes during build)
devtools::build(args = "--compact-vignettes=both")

## 3. Check the SOURCE package (source dir)
devtools::check()

## 4. Check the BUILT tarball (use check_built, not check)
file_check <- list.files("..", pattern = "partsm_.+\\.tar\\.gz")
devtools::check_built(path = file.path("..", file_check))


## Online Checks
# devtools::check_rhub(interactive = FALSE)
devtools::check_win_devel(args = "--compact-vignettes=both")
devtools::check_win_release(args = "--compact-vignettes=both")
devtools::check_win_oldrelease(args = "--compact-vignettes=both")

## 
# spelling::spell_check_setup(lang = "en-UK")
devtools::spell_check(use_wordlist = TRUE)

#
# usethis::use_cran_comments(open = FALSE)



## reverse dependency? not working well as of Nov 2020
# usethis::use_revdep()
# revdepcheck::revdep_check(num_workers = 4)

## Release
# devtools::release_checks()
devtools::submit_cran(args = "--compact-vignettes=both")

## Auxiliary functions.

ret <- function(vari, k)
{
  N <- length(vari)
  vret <- matrix(c(1:k*N),N,k)
  vret[,1] <- vari
  i <- 1
  while(i < k){
   vret[1:i,(i+1)] <- NA
   vret[(i+1):N, (i+1)] <- vari[1:(N-i)]
   i <- i+1
              }
  vret
}

ysooys <- function(yso, t0, N, s)
{
  index <- matrix(-9999, ncol=3, nrow=N)
  index[,3] <- c(1:N)
  index[,2] <- c(c(t0[2]:s), rep(1:s,N/s))[1:N]
  index[1:length(t0[2]:s),1] <- rep(t0[1], length(t0[2]:s))
  i <- 1
  while(index[N,1] == -9999)
  {
     iaux <- which(index[,1] == -9999)
     reps <- ifelse(length(iaux) >= s, reps <- s, reps <- length(iaux))
     index[iaux[1]:(iaux[1]+(reps-1)),1] <- rep(t0[1]+i, reps)
     i <- i+1
  }

# year and season to observation
  if(length(yso)==2)
  {
    quest1 <- which(c(index[,1] == yso[1]) == TRUE)
    quest2 <- which(c(index[,2] == yso[2]) == TRUE)
     i <- 1; out <- quest1[1]
    while(length(which(quest2 == quest1[i])) != 1){
      i <- i+1
      out <- quest1[i]
    }
  }

# observation to year and season
  if(length(yso)==1)
    out <- index[which(index[,3]==yso),1:2]

  list(out, index)
}

Dummy <- function(wts, y0, s0, yN, sN)
{
   aux   <- ysooys(1, start(wts), length(wts), frequency(wts))[[2]][,1]
   years <- seq(aux[1], aux[length(aux)])
   Mdum  <- rep(0, wts$N)
   obs0  <- (which(years==y0)-1) * frequency(wts) + s0
   obsN  <- (which(years==yN)-1) * frequency(wts) + sN
   Mdum[obs0:obsN] <- 1
   Mdum <- matrix(Mdum, ncol=1)
   Mdum
}

SeasDummy <- function(wts, s, t0, type)
{
  N <- length(wts)

  if(type == "alg"){        # Empleada en Barsky & Miron (1989)
   auxD <- matrix(0,nrow=N, ncol=s)
   sq   <- seq(1,N,s)
   k    <- 0

   for(j in 1:s){
     ifelse(sq[length(sq)] + k > N, n <- length(sq)-1, n <- N)
     for(i in 1:n)
       auxD[sq[i]+k,j] <- 1
     k <- k+1
   }
   VFE <- auxD
   if(t0[2] != 1){
      VFE <- matrix(nrow=N, ncol=s)
      VFE[,1:(t0[2]-1)] <- auxD[,(s-t0[2]+2):s]; VFE[,t0[2]:s] <- auxD[,1:(s-t0[2]+1)]
                  }
   if(t0[2] == 1){ VFE <- auxD }
  }

  if(type == "trg"){        # Empleada en Granger & Newbold (1986)
   qq  <- s/2
   VFE <- matrix(nrow=N, ncol=(s-1))

   sq1 <- seq(1,qq*2,2)
   sq2 <- seq(2,qq*2,2)
   j   <- c(1:(qq-1))

   for(i in 1:N){
     for(k in 1:(s-qq-1)){
         VFE[i,sq1[k]] <- cos((j[k]*pi/qq)*i)
         VFE[i,sq2[k]] <- sin((j[k]*pi/qq)*i)
     }
     VFE[i,(s-1)] <- (-1)^i
   }
  }
  VFE
}

## partsm functions.

fit.ar.par <- function(wts, type, detcomp, p)
{
  s <- frequency(wts)
  t0 <- start(wts)
  N <- length(wts)
  MLag <- ret(wts, (p+1))

  Interc <- rep(detcomp$regular[1], N)
  Trnd <- c(1:N)
  SDum <- SeasDummy(wts, s, t0, "alg")
  STrnd <- Trnd*SDum

  Mdetreg <- data.frame(Interc, Trnd, SeasDum=SDum)
  ref1 <- which(detcomp$regular != 0)
  aux1 <- Mdetreg[,ref1]

  Mdetreg <- data.frame(SeasDum=SDum, SeasTrnd=STrnd)
  ref2 <- c(detcomp$seasonal[1] * c(1:s), detcomp$seasonal[2] * c((s+1):(2*s)))
  aux2 <- Mdetreg[,ref2]

  if(length(detcomp$regvar) == 1)
    MDT <- as.matrix(data.frame(.=aux1, .=aux2))
  if(length(detcomp$regvar) > 1)
    MDT <- as.matrix(data.frame(.=aux1, .=aux2, RegVar=detcomp$regvar))

  switch(type,
    "AR" = {
            if(p == 0){
              lm.ar <- lm(MLag[,1] ~ 0+MDT)
              lm.par <- par.coeffs <- ar.coeffs <- NULL
              #out <- list(lm=lm1, sumlm=summary(lm1))
            }
            if(p > 0){
              lm.ar <- lm(MLag[,1] ~ 0+MLag[,2:(p+1)] + MDT)
              ar.coeffs <- matrix(lm.ar$coef[1:p], nrow=1, byrow=TRUE)
              lm.par <- par.coeffs <- NULL
              #out <- list(lm=lm1, sumlm=summary(lm1), ar.coeffs=lm.ar$coef[1:p])
            } },

    "PAR" = {
             if(p == 0){
               lm.par <- lm(MLag[,1] ~ 0+MDT); par.coeffs <- NULL
               lm.ar <- par.coeffs <- ar.coeffs <- NULL
               #out <- list(lm=lm1, sumlm=summary(lm1))
             }
             if(p > 0){
               Yperlag <- matrix(nrow=length(wts), ncol=(p*s))
               j <- 2; for(i in seq(1,(p*s),s)){
                 Yperlag[,i:(i+s-1)] <- MLag[,j]*SDum
                 j <- j+1
               }
               lm.par <- lm(MLag[,1] ~ 0+Yperlag + MDT)
               par.coeffs <- matrix(lm.par$coef[1:(p*s)], nrow=p, byrow=TRUE)
               lm.ar <- ar.coeffs <- NULL
               #out <- list(lm=lm1, sumlm=summary(lm1),
               #            ar.coeffs=matrix(lm.par$coef[1:(p*s)], nrow=p, byrow=TRUE))
             } }
  )
  ##~ out
  new("fit.partsm", type=type, p=p, lm.ar=lm.ar, lm.par=lm.par, ar.coeffs=ar.coeffs, par.coeffs=par.coeffs)
}

Fnextp.test <- function(wts, detcomp, p, type)
{
  if(type=="AR"){
    test.name <- "Test for the significance of the p+1 autoregressive parameters"
    lm1 <- fit.ar.par(wts, detcomp=detcomp, type=type, p=p)@lm.ar
    lm2 <- fit.ar.par(wts, detcomp=detcomp, type=type, p=p+1)@lm.ar
  }
  if(type=="PAR"){
    test.name <- "Test for the significance of the p+1 periodic autoregressive parameters"
    lm1 <- fit.ar.par(wts, detcomp=detcomp, type=type, p=p)@lm.par
    lm2 <- fit.ar.par(wts, detcomp=detcomp, type=type, p=p+1)@lm.par
  }

  RSS0 <- sum(lm1$residuals^2)
  RSS1 <- sum(lm2$residuals^2)

  df   <- c(frequency(wts), length(wts) - length(coef(lm2)) - p)
  Fnextp <- ((RSS0-RSS1)/df[1]) / (RSS1/(df[2]-df[1]))
  pval <- 1 - pf(q=Fnextp, df1=df[1], df2=df[2], log.p=FALSE)

  ref1 <- c(1, 0.1, 0.05, 0.01, 0.001)
  ref2 <- c(" ", ".", "*", "**", "***")
  pvl <- ref2[length(which(pval <= ref1) == TRUE)]

  new("Ftest.partsm", test.label="Fnextp", test.name=test.name, p=p,
      Fstat=Fnextp, df=df, pval=pval, pvl=pvl, h0md=lm1, hamd=lm2)
  ##~list(Fnextp=Fnextp, df=df, pvalue=pval, lm1=summary(lm1), lm2=summary(lm2))
}

Fpar.test <- function(wts, detcomp, p)
{
  urmd <- fit.ar.par(wts, type="PAR", detcomp, p)@lm.par
  rmd  <- fit.ar.par(wts, type="AR", detcomp, p)@lm.ar

  RSS0 <- sum(rmd$residuals^2)
  RSS1 <- sum(urmd$residuals^2)

  df   <- c((frequency(wts)-1)*p, length(wts) - length(coef(rmd)) - p)
  Fpar <- ((RSS0-RSS1)/df[1]) / (RSS1/(df[2]-df[1]))
  pval <- 1 - pf(q=Fpar, df1=df[1], df2=df[2], log.p=FALSE)

  ref1 <- c(1, 0.1, 0.05, 0.01, 0.001)
  ref2 <- c(" ", ".", "*", "**", "***")
  pvl <- ref2[length(which(pval <= ref1) == TRUE)]

  new("Ftest.partsm", test.label="Fpar", test.name="Test for periodicity in the autoregressive parameters",
      p=p, Fstat=Fpar, df=df, pval=pval, pvl=pvl, h0md=rmd, hamd=urmd)
  ##~list(Fpar=Fpar, df=df, pvalue=pval, urmd=summary(urmd), rmd=summary(rmd))
}

Fsh.test <- function(res, s)
{
  res2 <- res^2
  SDum <- SeasDummy(res2, s, c(1,1), "alg")

  lm1 <- lm(res2 ~ 1)
  lm2 <- update(lm1, . ~ . + SDum[,1:(s-1)])

  RSS0 <- sum(residuals(lm1)^2)
  RSS1 <- sum(residuals(lm2)^2)

  df <- c((s-1), length(res) - length(coef(lm1)))
  Fsh <- ((RSS0-RSS1)/df[1]) / (RSS1/(df[2]-df[1]))
  pval <- 1 - pf(q=Fsh, df1=df[1], df2=df[2], log.p=FALSE)

  ref1 <- c(1, 0.1, 0.05, 0.01, 0.001)
  ref2 <- c(" ", ".", "*", "**", "***")
  pvl <- ref2[length(which(pval <= ref1) == TRUE)]

  new("Ftest.partsm", test.label="Fsh", test.name="Test for seasonal heteroskedasticity",
      Fstat=Fsh, df=df, pval=pval, pvl=pvl, h0md=lm1, hamd=lm2)
}

##~ Representaci?n posible si las ra?ces del modelo en forma VQ son reales (ver).
fit.piar <- function(wts, detcomp, p, initvalues=NULL)
{
  if(p > 2)
    stop("This function is implemented only for PAR models up to order 2.\n")

# Create the matrix with all the possible regressors.

  s <- frequency(wts)
  N <- length(wts)
  ML <- ret(wts, (p+1))

  Interc <- rep(detcomp$regular[1], N)
  Trnd <- c(1:N)
  SDum <- SeasDummy(wts, s, start(wts), "alg")
  STrnd <- Trnd*SDum

  Mdetreg <- data.frame(Interc, Trnd, SeasDum=SDum)
  ref1 <- which(detcomp$regular != 0)
  aux1 <- Mdetreg[,ref1]

  Mdetreg <- data.frame(SeasDum=SDum, SeasTrnd=STrnd)
  ref2 <- c(detcomp$seasonal[1] * c(1:s), detcomp$seasonal[2] * c((s+1):(2*s)))
  aux2 <- Mdetreg[,ref2]

  if(length(detcomp$regvar) == 1)
    Mreg <- as.matrix(data.frame(.=aux1, .=aux2))
  if(length(detcomp$regvar) > 1)
    Mreg <- as.matrix(data.frame(.=aux1, .=aux2, RegVar=detcomp$regvar))

  Yperlag <- matrix(nrow=length(wts), ncol=(p*s))
  j <- 2
  for(i in seq(1,(p*s),s)){
    Yperlag[,i:(i+s-1)] <- ML[,j]*SDum
    j <- j+1
  }

  Mreg <- as.matrix(data.frame(Yperlag=Yperlag, Mreg=Mreg))

# Define the nls model for p=1 and p=2.

  aux.anlr <- paste("coef", 1:s, "*Mreg[,", 1:s, "]", sep="")
  nlr <- paste("(1/(", paste(paste("coef", 1:(s-1), sep=""), collapse="*"), "))", sep="")
  aux.anlr[s] <- paste(nlr, "*Mreg[,", s, "]", sep="")

  anlr <- paste(aux.anlr, collapse=" + ")

  if(p==2){
    aux.b <- paste("coef", s:(p*s-1), "*Mreg[,", 1:s, "]", sep="")
    b <- paste(aux.b, collapse=" + ")

    ref <- paste("coef", s:(p*s-1), "*coef", 0:(s-1), sep="")
    ref[1] <- paste("coef", s, "*", nlr, sep="")
    aux.ab <- paste(ref[1:s], "*Mreg[,", (s+1):(p*s), "]", sep="")
    ab <- paste(aux.ab, collapse=" - ")
  }

  if(ncol(Mreg) > (p*s))
    aux.det <- paste("coef", (s*p):(ncol(Mreg)-1), "*Mreg[,", (s*p+1):ncol(Mreg), "]", sep="")
  det <- paste(aux.det, collapse=" + ")

  if(p==1)
    form.rpar <- as.formula(paste("ML[,1] ~ ", paste(anlr, det, sep=" + ")))
  if(p==2)
    form.rpar <- as.formula(paste("ML[,1] ~ ", paste(anlr, b, sep=" + "), "-", paste(ab, det, sep=" + ")))

# Compute initial values for the nls model.

  if(inherits(initvalues, "NULL"))
  {
  if(p==1)
    init <- lm(ML[,1] ~ 0+Mreg)$coef[-s]

  #nlsinit <- list(init[1])
  #for(i in 2:length(init))
  #  nlsinit <- c(nlsinit, list(init[i]), recursive=FALSE)
  #names(nlsinit) <- paste("coef", 1:length(init), sep="")

  if(p==2){
    lmaux <- lm(ML[,1] ~ 0+Mreg[,-c((s+1):(s*2))])
    initalpha <- coef(lmaux)[1:s]

    filc <- rowSums(initalpha*SDum)
    regaux <- SDum*ML[,2] - filc*SDum*ML[,3]

    lmbeta <- lm((ML[2:N,1]-residuals(lmaux)) ~ 0+regaux[2:N,])
    initbeta <- coef(lmbeta)

    init <- c(initalpha[1:(s-1)], initbeta, coef(lmaux)[(s+1):length(coef(lmaux))])
  }
  }

  nlsinit <- list(init[1])
  for(i in 2:length(init))
    nlsinit <- c(nlsinit, list(init[i]), recursive=FALSE)
  names(nlsinit) <- paste("coef", 1:length(nlsinit), sep="")

# nls.

  nlsrpar <- summary(nls(form.rpar, start=nlsinit, trace=FALSE))

# Periodic differences of the original series.

  pdiff.coeffs <- c(coef(nlsrpar)[1:(s-1),1], (1/prod(coef(nlsrpar)[1:(s-1),1])))
  pdfilc <- rowSums(pdiff.coeffs*SDum)
  pdiff.data <- ts(ML[,1] - pdfilc * ML[,2], frequency=s, start=start(wts))

  if(p==1)
    par.coeffs <- matrix(pdiff.coeffs, nrow=p, byrow=TRUE)
  if(p>1 && p<=4)
    par.coeffs <- matrix(c(pdiff.coeffs, coef(nlsrpar)[((p-1)*s):(p*s-1),1]), nrow=p, byrow=TRUE)

  new("fit.piartsm", p=p, nls.parameters=nlsrpar$parameters, nls.res=nlsrpar$residuals, par.coeffs=par.coeffs,
      pdiff.data=pdiff.data)
  ## pdiff.coeffs=matrix(pdiff.coeffs, nrow=1)
  ##~list(nls.rpar=nlsrpar, parcoeffs=parcoeffs, pdiff.coeffs=matrix(pdiff.coeffs, nrow=1), pddata=pddata)
}

Fpari.piar.test <- function(wts, detcomp, p, type)
{
  ML  <- ret(wts, 3)
  SDum <- SeasDummy(wts, frequency(wts), start(wts), "alg")
  Y1  <- ML[,2]*SDum
  Y2  <- ML[,3]*SDum

  switch(type,
    "PARI1"  = MLh0d <- ts(ML[,1]-ML[,2], frequency=frequency(wts), start=start(wts)),
    "PARI-1" = MLh0d <- ts(ML[,1]+ML[,2], frequency=frequency(wts), start=start(wts))
  )

  if(p==1){
    h0md <- fit.ar.par(wts=MLh0d, detcomp=detcomp, type="AR", p=0)@lm.ar
    hamd <- fit.piar(wts=wts, detcomp=detcomp, p=1)
  }
  if(p==2){
    switch(type,
      "PARI1"  = MLr <- (ML[,2]-ML[,3])*SDum,
      "PARI-1" = MLr <- (ML[,2]+ML[,3])*SDum)

    ifelse(detcomp$regvar == 0,
      dch0 <- list(regular=detcomp$regular, seasonal=detcomp$seasonal, regvar=MLr),
      dch0 <- list(regular=detcomp$regular, seasonal=detcomp$seasonal,
                   regvar=as.matrix(data.frame(detcomp$regvar, MLr)))
    )
    h0md <- fit.ar.par(wts=MLh0d, detcomp=dch0, type="AR", p=0)@lm.ar
    hamd <- fit.piar(wts=wts, detcomp=detcomp, p=2)
  }

  RSS0 <- sum(residuals(h0md)^2)
  RSS1 <- sum(hamd@nls.res^2)

  df <- c((frequency(wts)-1), length(wts) - length(coef(h0md)) - p)
  Fstat <- ((RSS0-RSS1)/df[1]) / (RSS1/(df[2]-df[1]))
  pval <- 1 - pf(q=Fstat, df1=df[1], df2=df[2], log.p=FALSE)

  ref1 <- c(1, 0.1, 0.05, 0.01, 0.001)
  ref2 <- c(" ", ".", "*", "**", "***")
  pvl <- ref2[length(which(pval <= ref1) == TRUE)]

  new("Ftest.partsm", test.label=paste("F", type, sep="-"),
      test.name="Test for a parameter restriction in a PAR model", p=p,
      Fstat=Fstat, df=df, pval=pval, pvl=pvl, h0md=h0md, hamd=hamd@nls.parameters)
  ##~list(Fstat=Fstat, df=df, pvalue=pval, h0md=summary(h0md), hamd=summary(hamd))
}

LRurpar.test <- function(wts, detcomp, p)
{
  if(p > 2)
    stop("This function is implemented only for PAR models up to order 2.\n")

  lmpar <- fit.ar.par(wts, type="PAR", detcomp=detcomp, p=p)
  par.phis <- lmpar@par.coeffs
  RSS1 <- sum(residuals(lmpar@lm.par)^2)

  nlsrpar <- fit.piar(wts=wts, detcomp=detcomp, p=p)
  RSS0 <- sum(nlsrpar@nls.res^2)

  n <- length(residuals(lmpar@lm.par))
  LR <- n * log(RSS0/RSS1, base = exp(1))
  LRtau <- sign(prod(par.phis[1,]) - 1) * sqrt(LR)
  ##~ poner output de fit.ar.par como lista en la que se nombre a alpha y beta, en lugar de coger la primera fila de una matriz para hacer prod(par.phis[1,]).

  new("LRur.partsm", test.label="LRurpar",
      test.name="Likelihood ratio test for a single unit root in a PAR model", p=p,
      LR=LR, LRtau=LRtau, h0nls=nlsrpar@nls.parameters, halm=lmpar@lm.par)
  ##~ list(LR=LR, LRtau=LRtau)
}

##~ Hacer predictpiar usando m?todos para cada parte, PAR.MVrepr, Omegas,...
predictpiar <- function(wts, p, hpred)
{
  t0 <- start(wts)
  N <- length(wts)
  s <- frequency(wts)

  sdetcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
  nlspiar <- fit.piar(wts=wts, detcomp=sdetcomp, p=p)
  nlscoef <- nlspiar@nls.parameters[,1]

  pred.se <- matrix(nrow=as.integer(hpred/s), ncol=s)
  sigma <- sd(nlspiar@nls.res)

  #phi <- matrix(nlspiar@par.coeffs[1,], nrow=1)
  #MPhi <- PAR.MVrepr(phi=phi, s=s)
  MV.out <- PAR.MVrepr(nlspiar)
  Phi0 <- MV.out@Phi0
  Phi1 <- MV.out@Phi1

  if(p==1)
  {
  # Forecast standard error for h=1.

    pred.se[1,] <- sqrt( sigma^2 * diag(solve(Phi0) %*% t(solve(Phi0))) )

  # Forecast standard error for h=2,3,...,hpred/s.

    Gamma <- solve(Phi0) %*% Phi1
    for(h in 2:(hpred/s))
      pred.se[h,] <- sqrt( sigma^2 * diag(
                       (solve(Phi0) %*% t(solve(Phi0)) +
                        (h-1) * (Gamma %*% solve(Phi0)) %*% t(Gamma %*% solve(Phi0)))) )

  # Forecast.

    mus <- matrix(nlscoef[(p*s):((p+1)*s-1)], ncol=1)
    pred <- matrix(nrow=as.integer(hpred/s), ncol=s)
    Yret1 <- matrix(wts[(N-s+1):N], ncol=1)

    for(i in 1:as.integer(hpred/s)){
      #pred[i,] <- solve(Phi0) %*% mus + solve(Phi0) %*% Phi1 %*% Yret1
      pred[i,] <- solve(Phi0) %*% mus + Gamma %*% Yret1
      Yret1 <- matrix(pred[i,], ncol=1)
    }
  }

  if(p==2)
  {
    albe <- nlspiar@par.coeffs
    Omega0 <- MV.out@Omega0
    Omega1 <- MV.out@Omega1
    Pi0 <- MV.out@Pi0
    Pi1 <- MV.out@Pi1

    Gamma <- solve(Phi0) %*% Phi1

    Xi <- list()
    Xi[[1]] <- Pi0
    for(i in 2:(hpred/s)){
      Xi[[i]] <- Gamma %*% Xi[[i-1]] + prod(albe[2,])^(i-2) * Pi1
    }

  # Forecast standard error for h=1.

    pred.se[1,] <- sqrt(sigma^2 * diag(Xi[[1]] %*% t(Xi[[1]])))

  # Forecast standard error for h=2,3,...,hpred/s.

    aux1 <- Xi[[1]] %*% t(Xi[[1]])
    for(h in 2:(hpred/s)){
      aux2 <- 0
      for(i in 2:h)
        aux2 <- aux2 + Xi[[i]] %*% t(Xi[[i]])
      pred.se[h,] <- sqrt(sigma^2 * diag(aux1 + aux2))
    }

  # Forecast.

    mus <- matrix(nlscoef[(p*s):((p+1)*s-1)], ncol=1)
    pred <- matrix(nrow=as.integer(hpred/s), ncol=s)
    Yret1 <- matrix(wts[(N-s+1):N], ncol=1)
    musx <- (1-prod(albe[2,]))^(-1) * (Omega0 + Omega1) %*% mus
    for(i in 1:as.integer(hpred/s)){
      #pred[i,] <- solve(Phi0) %*% mus + solve(Phi0) %*% Phi1 %*% Yret1
      pred[i,] <- solve(Phi0) %*% musx + Gamma %*% Yret1
      Yret1 <- matrix(pred[i,], ncol=1)
    }
  }

# Confidence intervals.

  #tl <- tu <- rep(NA, hpred); k <- 1
  tl <- tu <- matrix(NA, nrow=(hpred/s), ncol=s)
  for(i in 1:nrow(pred.se)){
    for(j in 1:s)
    {
      #tl[k] <- pred[k] - 1.96 * pred.se[i,j]
      #tu[k] <- pred[k] + 1.96 * pred.se[i,j]
      #k <- k+1
      tl[i,j] <- pred[i,j] - 1.96 * pred.se[i,j]
      tu[i,j] <- pred[i,j] + 1.96 * pred.se[i,j]
    }
  }

  t0aux <- ysooys(N, t0, N+1, s)
  t0p <- t0aux[[2]][(N+1),1:2]
  fcast <- ts(matrix(t(pred), ncol=1), frequency=s, start=t0p)
  fse <- ts(matrix(t(pred.se), ncol=1), frequency=s, start=t0p)
  ucb <- ts(matrix(t(tu)), frequency=s, start=t0p)
  lcb <- ts(matrix(t(tl)), frequency=s, start=t0p)

  new("pred.piartsm", wts=wts, p=p, hpred=hpred, fcast=fcast, fse=fse, ucb=ucb, lcb=lcb)
  ##~list(output, sigma=sigma, pred.se=pred.se)
}

plotpredpiar <- function(x){
  if (!inherits(x, "pred.piartsm"))
    stop("\n Object is not of class 'pred.piartsm'.\n")

  opar <- par(las=1)
  ts.plot(x@wts, x@lcb, x@ucb, x@fcast, lty = c(1,2,2,1), xlab="",
          col=c("black","red","red","blue"), main="Forecast and confidence intervals")
  par(opar)
}

## Set classes.

setClass("fit.partsm", representation(type="character", p="numeric", lm.ar="ANY", lm.par="ANY",
         ar.coeffs="ANY", par.coeffs="ANY"))

setClass("fit.piartsm", representation(p="numeric", nls.parameters="matrix", nls.res="numeric",
         par.coeffs="matrix", pdiff.data="ts"))

setClass("Ftest.partsm", representation(test.label="character", test.name="character", p="numeric",
         Fstat="numeric", df="numeric", pval="numeric", pvl="character", h0md="lm", hamd="ANY"))

setClass("LRur.partsm", representation(test.label="character", test.name="character", p="numeric",
         LR="numeric", LRtau="numeric", h0nls="matrix", halm="lm"))

setClass("pred.piartsm", representation(wts="ts", hpred="numeric", p="numeric", fcast="ts", fse="ts",
         ucb="ts", lcb="ts"))

setClass("MVPAR", representation(Phi0="matrix", Phi1="matrix", Gamma.eigenvalues="numeric",
         tvias="matrix"))

setClass("MVPIAR", representation(Phi0="matrix", Phi1="matrix", Gamma.eigenvalues="numeric",
         tvias="matrix", Omega0="ANY", Omega1="ANY", Pi0="ANY", Pi1="ANY"))

## Set methods for classes.

setMethod("show", "fit.partsm",
  function(object)
  {
    if(object@type == "AR"){
      ar.coeffs <- object@ar.coeffs
      model <- paste("  y_t = phi_1*y_{t-1} + phi_2*y_{t-2} + ... + phi_p*y_{t-p} + coeffs*detcomp + epsilon_t \n")
      dimnames(ar.coeffs) <- list("phi_p", paste("p=", 1:ncol(ar.coeffs), sep=""))
    }
    if(object@type == "PAR"){
      par.coeffs <- object@par.coeffs
      model <- paste("  y_t = alpha_{1,s}*y_{t-1} + alpha_{2,s}*y_{t-2} + ... + alpha_{p,s}*y_{t-p} + coeffs*detcomp + epsilon_t,  for s=1,2,...,", ncol(par.coeffs), "\n", sep="")

      dimnames(par.coeffs) <- list(paste("alpha_", 1:nrow(par.coeffs), "s", sep=""),
                                   paste("s=", 1:ncol(par.coeffs), sep=""))
    }

    cat("----\n ", paste(object@type, "model of order", object@p, ".\n\n"))
    cat(model)

    if(object@type == "AR"){
      if(object@p == 0)
        cat("----\n  None autoregressive lags (p=0). \n\n")
      if(object@p > 0){
        cat("----\n  Autoregressive coefficients. \n\n")
        print(round(ar.coeffs, 2)); cat("\n")
      }
    }
    if(object@type == "PAR"){
      if(object@p == 0)
        cat("----\n  None periodic autoregressive lags (p=0). \n\n")
      if(object@p > 0){
        cat("----\n  Autoregressive coefficients. \n\n")
        print(round(par.coeffs, 2)); cat("\n")
      }
    }
  }
)

setMethod("summary", "fit.partsm",
  function(object)
  {
    show(object)
    if(object@type == "AR")
      print(summary(object@lm.ar))
    if(object@type == "PAR")
      print(summary(object@lm.par))
  }
)

##~ A?adir slot con detcomp (.Rd), y poner en la primera l?nea de cat.
setMethod("show", "fit.piartsm",
  function(object)
  {
    model <- c(paste("  y_t - alpha_s*y_{t-1} = beta_s*(y_{t-1} - alpha_{s-1}*y_{t-2}) + \n"),
               paste("                         coeffs*detcomp + epsilon_t,  with prod(alpha_s=1) for s=1,2,...,",  ncol(object@par.coeffs), ".\n", sep=""))

    if(nrow(object@par.coeffs) == 1)
      dimnames(object@par.coeffs) <- list(c("  alpha_s"),
                                          paste("s=", 1:ncol(object@par.coeffs), sep=""))
    if(nrow(object@par.coeffs) == 2)
      dimnames(object@par.coeffs) <- list(c("  alpha_s", "  beta_s"),
                                          paste("s=", 1:ncol(object@par.coeffs), sep=""))

    cat("----\n ", paste("PIAR model of order", object@p, ".\n\n"))
    cat(model)

    cat("\n  Periodic autoregressive coefficients: \n\n")
    print(round(object@par.coeffs, 3)); cat("\n")
  }
)

setMethod("summary", "fit.piartsm",
  function(object, digits = max(3L, getOption("digits") - 3L),
           signif.stars = getOption("show.signif.stars"))
  {
    show(object)
    cat("----\n  Estimates of the non-linear model.\n")
    printCoefmat(object@nls.parameters, digits=digits, signif.stars=signif.stars)
    cat("\n----\n  Periodically differenced data.\n")
    print(round(object@pdiff.data, digits=digits)); cat("\n")
  }
)

#setMethod("plot", signature(x="fit.piartsm", y="missing"),
#  function(x){
#    opar <- par(las=1)
#    layout(matrix(c(1, 1, 2, 3), 2 , 2, byrow=TRUE))
#    plot(x@pdiff.data, main="Periodically differenced data", ylab="", xlab="")
#    bbplot(x@pdiff.data)
#    monthplot(x@pdiff.data, ylab="")
#    ##acf(x@pdiff.data, main="Autocorrelations", ylab="", na.action=na.pass)
#    ##pacf(x@pdiff.data, main="Partial autocorrelations", ylab="", na.action=na.pass)
#    par(opar)
#  }
#)
##~ monthplot, main="Seasonal subseries"

setMethod("show", "Ftest.partsm",
  function(object)
  {
    cat("----\n ", object@test.name, ".\n\n")

    if(object@test.label=="Fpar"){
      cat("  Null hypothesis: AR(", object@p, ") with the selected deterministic components.\n")
      cat("  Alternative hypothesis: PAR(", object@p, ") with the selected deterministic components.\n\n")
    }

    if(object@test.label=="Fsh"){
      ##~ HACER.
    }

    if(object@test.label=="Fnextp"){
      ifelse(substr(object@test.name, 38, 45) == "periodic", type <- "PAR", type <- "AR")
      cat("  Null hypothesis:", type, "(", object@p, ") with the selected deterministic components.\n")
      cat("  Alternative hypothesis:", type, "(", object@p+1, ") with the selected deterministic components.\n\n")
    }

    if(object@test.label=="F-PARI1" && object@test.label=="F-PARI-1"){
      switch(object@test.label,
        "F-PARI1"  = H0cat <- "long run unit root 1",
        "F-PARI-1" = H0cat <- "seasonal unit root -1")
      cat("  Null hypothesis: PAR(", object@p, ") for a series with the", H0cat, "\n")
      cat("  Alternative hypothesis: Periodically integrated AR(", object@p, "). \n\n")
    }

    cat("  F-statistic:", round(object@Fstat, 2), "on", object@df[1], "and", object@df[2], "DF,", "p-value:", object@pval, object@pvl, "\n\n")
    cat("  Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 \n\n")
  }
)

setMethod("summary", "Ftest.partsm",
  function(object)
  {
    show(object)
    cat("----\n----\n## Fitted model for the null hypothesis.\n")
    print(summary(object@h0md))
    cat("----\n----\n## Fitted model for the alternative hypothesis.\n")
    print(summary(object@hamd))
  }
)

setMethod("show", "LRur.partsm",
  function(object)
  {
    cat("----\n ", c(object@test.name, "of order", object@p, ".\n\n"))

    cat("  Null hypothesis: PAR(", object@p, ") restricted to a unit root. \n")
    cat("  Alternative hypothesis: PAR(", object@p, "). \n\n")

    cat("  LR-statistic:", round(object@LR, 2), "\n  ---\n")
    cat("  5 and 10 per cent asymptotic critical values:\n")
    cat("    when seasonal intercepts are included: 9.24, 7.52. \n")
    cat("    when seasonal intercepts and trends are included: 12.96, 10.50. \n\n")

    cat("  LRtau-statistic:", round(object@LRtau, 2), "\n  ---\n")
    cat("  5 and 10 per cent asymptotic critical values:\n")
    cat("    when seasonal intercepts are included: -2.86, -2.57. \n")
    cat("    when seasonal intercepts and trends are included: -3.41, -3.12. \n\n")
  }
)

setMethod("summary", "LRur.partsm",
  function(object)
  {
    show(object)
    cat("----\n----\n## Fitted model for the null hypothesis.\n")
    print(object@h0nls)
    cat("----\n----\n## Fitted model for the alternative hypothesis.\n")
    print(object@halm)
  }
)

setMethod("show", "pred.piartsm",
  function(object)
  {
    yd <- as.integer(time(object@fcast))
    sd <- cycle(object@fcast)

    ysd <- rep(NA, object@hpred)
    for(i in 1:object@hpred){
      ifelse(nchar(sd[i]) == 1, sdi <- paste("0", sd[i], sep=""), sdi <- sd[i])
      ysd[i] <- paste(yd[i], sdi, sep=".")
    }

    out <- data.frame(object@fcast, object@fse, object@ucb, object@lcb)
    dimnames(out) <- list(ysd, c("fcast", "fse", "ucb", "lcb"))

    cat("----\n ", paste("  Forecasts for a PIAR model of order", object@p, ".\n\n"))
    print(out)
    cat("\n  'fcast': Forecast; 'fse': Forecast standard error; \n")
    cat("  'ucb': Upper confidence bound; 'lcb': Lower condidence bound. \n\n")
  }
)

PAR.MVrepr <- function(object)
{
   if(!inherits(object, c("fit.par sm", "fit.piartms")))
     stop("Object is not of class 'fit.partsm' or 'fit.piartsm'.\n")
}

setMethod("PAR.MVrepr", "fit.partsm",
  function(object)
  {
    if(is.null(object@par.coeffs))
      stop("Object is related to an AR model. A PAR model must be provided.\n")

    phi <- object@par.coeffs; s <- ncol(phi)
    Phi01 <- .PAR.MV(phi=phi, s=s)

    new("MVPAR", Phi0=Phi01$Phi0, Phi1=Phi01$Phi1, Gamma.eigenvalues=Phi01$Phi01ev, tvias=Phi01$tvias)
  }
)

setMethod("PAR.MVrepr", "fit.piartsm",
  function(object)
  {
    phi <- matrix(object@par.coeffs[1,], nrow=1)
    s <- ncol(phi); p <- nrow(object@par.coeffs)

    Phi01 <- .PAR.MV(phi=phi, s=s)
    Phi0 <- Phi01$Phi0
    Phi1 <- Phi01$Phi1

    if(p==1)
      Omega0 <- Omega1 <- Pi0 <- Pi1 <- NULL
    if(p==2)
    {
      albe <- object@par.coeffs

      Omega0 <- diag(1, s)
      for(i in 2:s)
        Omega0[i,(i-1)] <- albe[2,i]
      Omega0[3,1] <- albe[2,2]*albe[2,3]
      Omega0[4,1] <- albe[2,2]*albe[2,3]*albe[2,4]
      Omega0[4,2] <- albe[2,3]*albe[2,4]

      Omega1 <- diag(0, s)
      Omega1[1,4] <- albe[2,1]
      Omega1[1,2] <- albe[2,1]*albe[2,3]*albe[2,4]
      Omega1[1,3] <- albe[2,1]*albe[2,4]
      Omega1[2,3] <- albe[2,1]*albe[2,2]*albe[2,4]
      Omega1[2,4] <- albe[2,1]*albe[2,2]
      Omega1[3,4] <- albe[2,1]*albe[2,2]*albe[2,3]

      Pi0 <- solve(Phi0) %*% Omega0
      Pi1 <- solve(Phi0) %*% Omega1 + prod(albe[2,]) * Pi0
    }

    new("MVPIAR", Phi0=Phi01$Phi0, Phi1=Phi01$Phi1, Gamma.eigenvalues=Phi01$Phi01ev, tvias=Phi01$tvias,
        Omega0=Omega0, Omega1=Omega1, Pi0=Pi0, Pi1=Pi1)
  }
)

setMethod("show", "MVPAR",
  function(object)
  {
    Phi0 <- round(object@Phi0, 3)
    Phi1 <- round(object@Phi1, 3)
    tvias <- round(object@tvias, 3)
    Gev <- round(object@Gamma.eigenvalues, 3)

    dimnames(Phi0) <- list(rep("", nrow(Phi0)), rep("", nrow(Phi0)))
    dimnames(Phi1) <- list(rep("", nrow(Phi1)), rep("", nrow(Phi1)))
    dimnames(tvias) <- list(rep("", nrow(tvias)), rep("", nrow(tvias)))

    cat("----\n ", paste("  Multivariate representation of a PAR model.\n\n"))

    cat("\n  Phi0:\n")
    print(Phi0); cat("\n")
    cat("\n  Phi1:\n")
    print(Phi1); cat("\n")
    cat("\n  Eigen values of Gamma = Phi0^{-1} %*% Phi1:\n")
    cat(Gev, "\n")
    cat("\n  Time varying accumulation of shocks:\n")
    print(tvias); cat("\n")
  }
)

setMethod("show", "MVPIAR",
  function(object)
  {
    Phi0 <- round(object@Phi0, 3)
    Phi1 <- round(object@Phi1, 3)
    tvias <- round(object@tvias, 3)
    Gev <- round(object@Gamma.eigenvalues, 3)

    dimnames(Phi0) <- list(rep("", nrow(Phi0)), rep("", nrow(Phi0)))
    dimnames(Phi1) <- list(rep("", nrow(Phi1)), rep("", nrow(Phi1)))
    dimnames(tvias) <- list(rep("", nrow(tvias)), rep("", nrow(tvias)))

    cat("----\n ", paste("  Multivariate representation of a PIAR model.\n\n"))

    cat("\n  Phi0:\n")
    print(Phi0); cat("\n")
    cat("\n  Phi1:\n")
    print(Phi1); cat("\n")
    cat("\n  Eigen values of Gamma = Phi0^{-1} %*% Phi1:\n")
    cat(Gev, "\n")
    cat("\n  Time varying accumulation of shocks:\n")
    print(tvias); cat("\n")
  }
)

##~ Internal functions.

.PAR.MV <- function(phi, s)
{
  paux <- length(phi)/s
  P <- 1 + as.integer((paux-1)/s)

  Phi0 <- matrix(0, nrow=s, ncol=s) # ver elemento (s,1)
  for(i in 1:s){
    for(j in 1:s){
      if(i==j){ Phi0[i,j] <- 1 }
      if(j>i) { Phi0[i,j] <- 0 }
      if(j<i && (i-j) <= paux) { Phi0[i,j] <- -phi[i-j,i] }
    }
  }

  for(k in 1:P){
    #Phik <- matrix(0, nrow=s, ncol=s*P)
    Phik <- matrix(0, nrow=s, ncol=s)
    for(i in 1:s){
      for(j in 1:s)
        if(i+s*k-j <= paux) Phik[i,j] <- phi[i+s*k-j,i]
    }
    MPhi <- as.matrix(data.frame(Phi0, Phik))
  }

  Phi0 <- MPhi[,1:s]
  Phi1 <- MPhi[,(s+1):(2*s)]

  Gamma <- solve(Phi0) %*% Phi1
  Phi01ev <- eigen(Gamma, only.values = TRUE)$values
  tvias <- Gamma %*% solve(Phi0)  # Time-varying impact of accumulation of shocks

  list(Phi0=Phi0, Phi1=Phi1, Phi01ev=Phi01ev, tvias=tvias)
}



##~ monthplot, main="Seasonal subseries"

acf.ext1 <- function(wts, transf.type, perdiff.coeffs, type, lag.max, showcat, plot)
{

  switch(transf.type,
    orig    = out <- acf(wts, type=type, lag.max=lag.max,
                         plot=plot, na.action=na.exclude),
    fdiff   = out <- acf(diff(wts, lag=1), type=type, lag.max=lag.max,
                         plot=plot, na.action=na.exclude),
    sdiff   = out <- acf(diff(wts, lag=frequency(wts)), type=type, lag.max=lag.max,
                         plot=plot, na.action=na.exclude),
    fsdiff  = out <- acf(diff(diff(wts, lag=1), lag=frequency(wts)), type=type,
                         lag.max=lag.max, plot=plot, na.action=na.exclude),
    fdiffsd = { MLd <- c(NA, diff(wts, lag=1))
                SDum <- SeasDummy(wts, frequency(wts), start(wts), "alg")
                res <- lm(MLd ~ 0+SDum[,1:frequency(wts)])$residuals
                out <- acf(res, type=type, lag.max=lag.max, plot=plot, na.action=na.exclude) },

    perdiff = { ML <- ret(wts, 2)
                SDum <- SeasDummy(wts, frequency(wts), start(wts), "alg")
                filc <- rowSums(perdiff.coeffs*SDum)
                MLd <- ML[,1] - filc * ML[,2]
                out <- acf(MLd, type=type, lag.max=lag.max, plot=plot, na.action=na.exclude) },

    perdiffsd = { ML <- ret(wts, 2)
                  SDum <- SeasDummy(wts, frequency(wts), start(wts), "alg")
                  filc <- rowSums(perdiff.coeffs*SDum)
                  MLd <- ML[,1] - filc * ML[,2]
                  res <- lm(MLd ~ 0+SDum[,1:frequency(wts)])$residuals
                  out <- acf(res, type=type, lag.max=lag.max, plot=plot, na.action=na.exclude) }

  )

  se  <- 1/sqrt(out$n.used)
  tst <- out$acf/se

  ref1 <- c(1, 0.1, 0.05, 0.01, 0.001)
  ref2 <- c(" ", ".", "*", "**", "***")

  pval <- pvl <- rep(NA, length(tst))
  for(i in 1:length(tst)){
    pval[i] <- (1-pnorm(q=abs(tst[i]), mean=0, sd=1, lower.tail=TRUE, log.p=FALSE)) * 2
    pvl[i] <- ref2[length(which(ref1 >= pval[i]) == TRUE)]
  }

  if(showcat == TRUE){
    sout <- data.frame(Lag=c(0:(length(tst)-1)), acf=round(out$acf,3), pvalue=round(pval,3), pvl)
    cat("----\n  Estimated autocorrelation function for the\n")
    switch(transf.type,
      orig    = cat("  original series.\n\n"),
      fdiff   = cat("  first differences of the original series.\n\n"),
      sdiff   = cat("  seasonal differences of the original series.\n\n"),
      fsdiff  = cat("  fisrt and seasonal differences of the original series.\n\n"),
      fdiffsd = cat("  residuals of the first differences on four seasonal dummy variables.\n\n"),
      perdiff = cat("  periodic differences of the original series.\n\n"),
      perdiffsd = cat("  residuals of the periodic differences on four seasonal dummy variables.\n\n")
    )

    print(sout)
    cat("\n  s.e.=", round(se, 2), "\n")
    cat("  Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1 \n")
  }

  out <- data.frame(Lag=c(0:(length(tst)-1)), acf=out$acf, pvalue=pval, pvl)
  list(acf=out, se=se)
}

library(partsm)

###########################
###### acf.ext1
###########################

data("gergnp")
lgergnp <- log(gergnp, base=exp(1))

out <- acf.ext1(wts=lgergnp, transf.type="orig",
                type="correlation", lag.max=12, showcat=TRUE, plot=FALSE)

out <- acf.ext1(wts=lgergnp, transf.type="perdiffsd", perdiff.coeff = c(1.004, 0.981, 1.047, 0.969),
                type="correlation", lag.max=12, showcat=TRUE, plot=FALSE)

###########################
###### fit.ar.par
###########################

## Models for the the logarithms of the Real GNP in Germany.
data("gergnp")
lgergnp <- log(gergnp, base=exp(1))

## Fit an AR(4) model with intercept and seasonal dummies.
detcomp <- list(regular=c(1,0,c(1,2,3)), seasonal=c(0,0), regvar=0)
out.ar <- fit.ar.par(wts=lgergnp, type="AR", detcomp=detcomp, p=4)

## Fit a PAR(2) model with seasonal intercepts.
detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
out.par <- fit.ar.par(wts=lgergnp, type="PAR", detcomp=detcomp, p=2)

###########################
###### fit.piar
###########################

## Fit a PIAR(2) model for the logarithms of the Real GNP in Germany.
data("gergnp")
lgergnp <- log(gergnp, base=exp(1))
detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
out <- fit.piar(wts=lgergnp, detcomp=detcomp, p=2, initvalues=NULL)

###########################
###### Fnextp.test
###########################

## Test the significance of a second order lag in a PAR model for the Real GNP in Germany.
## Including seasonal intercepts.
data("gergnp")
lgergnp <- log(gergnp, base=exp(1))
detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
out <- Fnextp.test(wts=lgergnp, detcomp=detcomp, p=1, type="PAR")

###########################
###### Fpar.test
###########################

## Test for periodicity in a second order PAR model for
## the logarithms of the Real GNP in Germany time series.
data("gergnp")
lgergnp <- log(gergnp, base=exp(1))
detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
out <- Fpar.test(wts=lgergnp, detcomp=detcomp, p=2)


###########################
###### Fpari.piar.test
###########################

## Test for the unit root 1 in a PAR(2) with seasonal intercepts for
## the logarithms of the Real GNP in Germany.
data("gergnp")
lgergnp <- log(gergnp, base=exp(1))
detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
out <- Fpari.piar.test(wts=lgergnp, detcomp=detcomp, p=2, type="PARI1")

###########################
###### Fsh.test
###########################

## Fsh test for the residuals of the first differences
## of the logarithms of the Real GNP in Germany
## on an AR(4) model with seasonal intercepts.
data("gergnp")
lgergnp <- log(gergnp, base=exp(1))
wts <- ts(c(NA, diff(gergnp, lag=1)), frequency=4, start=start(lgergnp))

detcomp=list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
ar4 <- fit.ar.par(wts=lgergnp, type="AR", p=4, detcomp=detcomp)
out <- Fsh.test(res=residuals(ar4@lm.ar), s=frequency(wts))

###########################
###### LRurpar.test
###########################

## Test for a single unit root in a PAR(2) model with seasonal intercepts for the
## logarithms of the Real GNP in Germany.
data("gergnp")
lgergnp <- log(gergnp, base=exp(1))
detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
out <- LRurpar.test(wts=lgergnp, detcomp=detcomp, p=2)

###########################
###### PAR.MVrepr
###########################

## Models for the the logarithms of the Real GNP in Germany.
data("gergnp")
lgergnp <- log(gergnp, base=exp(1))

## Fit an PAR model
detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
out.par <- fit.ar.par(wts=lgergnp, type="PAR", detcomp=detcomp, p=2)

## Show the matrix representation: 
out.MV <- PAR.MVrepr(out.par)
out.MV

###########################
###### PAR.MVrepr-methods
###########################

## Load data and select the deterministic components.
data("gergnp")
lgergnp <- log(gergnp, base=exp(1))
detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)

## Multivariate representation of a PAR(2) model with sesonal intercepts.
out.par <- fit.ar.par(wts=lgergnp, type="PAR", detcomp=detcomp, p=2)
PAR.MVrepr(out.par)

## Multivariate representation of a PIAR(2) model with sesonal intercepts.
out.piar <- fit.piar(wts=lgergnp, detcomp=detcomp, p=2)
PAR.MVrepr(out.piar)

###########################
###### plotpdiff
###########################

## Load data and select the deterministic components.
data("gergnp")
lgergnp <- log(gergnp, base=exp(1))
detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)

## Fit a PIAR(2) model with seasonal intercepts.
out.piar <- fit.piar(wts=lgergnp, detcomp=detcomp, p=2)
plotpdiff(out.piar)

###########################
###### plotpredpiar
###########################

## Load data and select the deterministic components.
data("gergnp")
lgergnp <- log(gergnp, base=exp(1))

## Fit a PIAR(2) model with seasonal intercepts.
out.pred <- predictpiar(wts=lgergnp, p=2, hpred=24)
plotpredpiar(out.pred)

###########################
###### predictpiar
###########################

## 24 step-ahead forecasts in a PIAR(2) model for the
## logarithms of the Real GNP in Germany.
data("gergnp")
lgergnp <- log(gergnp, base=exp(1))
pred.out <- predictpiar(wts=lgergnp, p=2, hpred=24)

###########################
###### show-methods
###########################

## Load data and select the deterministic components.
data("gergnp")
lgergnp <- log(gergnp, base=exp(1))
detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)

## Fit an AR(4) model with intercept and seasonal dummies.
dcar <- list(regular=c(1,0,c(1,2,3)), seasonal=c(0,0), regvar=0)
out.ar <- fit.ar.par(wts=lgergnp, type="AR", detcomp=dcar, p=4)
show(out.ar)

## Fit a PAR(2) model with seasonal intercepts.
out.par <- fit.ar.par(wts=lgergnp, type="PAR", detcomp=detcomp, p=2)
show(out.par)

## Fnextp.test
Fnextp.out <- Fnextp.test(wts=lgergnp, detcomp=detcomp, p=1, type="PAR")
show(Fnextp.out)

## Fpar.test
Fpar.out <- Fpar.test(wts=lgergnp, detcomp=detcomp, p=2)
show(Fpar.out)

## Fsh.test
ar4 <- fit.ar.par(wts=lgergnp, type="AR", p=4, detcomp=detcomp)
Fsh.out <- Fsh.test(res=residuals(ar4@lm.ar), s=frequency(lgergnp))
show(Fsh.out)

## Fit a PIAR(2) model with seasonal intercepts.
out.piar <- fit.piar(wts=lgergnp, detcomp=detcomp, p=2)
show(out.piar)

## Fpari.piar.test
Fpari1.out <- Fpari.piar.test(wts=lgergnp, detcomp=detcomp, p=2, type="PARI1")
show(Fpari1.out)

## Fit a PIAR(2) model with seasonal intercepts.
out.piar <- fit.piar(wts=lgergnp, detcomp=detcomp, p=2)
show(out.piar)

## Test for a single unit root in a PAR(2) model with seasonal intercepts.
out.LR <- LRurpar.test(wts=lgergnp, detcomp=detcomp, p=2)
show(out.LR)

## 24 step-ahead forecasts in a PIAR(2) model.
pred.out <- predictpiar(wts=lgergnp, p=2, hpred=24)
options(digits=4)
show(pred.out)
options(digits=7)

###########################
###### summary-methods
###########################

## Load data and select the deterministic components.
data("gergnp")
lgergnp <- log(gergnp, base=exp(1))
detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)

## Fit an AR(4) model with intercept and seasonal dummies.
dcar <- list(regular=c(1,0,c(1,2,3)), seasonal=c(0,0), regvar=0)
out.ar <- fit.ar.par(wts=lgergnp, type="AR", detcomp=dcar, p=4)
summary(out.ar)

## Fit a PAR(2) model with seasonal intercepts.
detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
out.par <- fit.ar.par(wts=lgergnp, type="PAR", detcomp=detcomp, p=2)
summary(out.par)

## Fnextp.test
Fnextp.out <- Fnextp.test(wts=lgergnp, detcomp=detcomp, p=1, type="PAR")
summary(Fnextp.out)

## Fpar.test
Fpar.out <- Fpar.test(wts=lgergnp, detcomp=detcomp, p=2)
summary(Fpar.out)

## Fsh.test
ar4 <- fit.ar.par(wts=lgergnp, type="AR", p=4, detcomp=detcomp)
Fsh.out <- Fsh.test(res=residuals(ar4@lm.ar), s=frequency(lgergnp))
summary(Fsh.out)

## Fit a PIAR(2) model.
out.piar <- fit.piar(wts=lgergnp, detcomp=detcomp, p=2)
summary(out.piar, digits=1)

## Fpari.piar.test
Fpari1.out <- Fpari.piar.test(wts=lgergnp, detcomp=detcomp, p=2, type="PARI1")
Fpari1.out
# options(digits=3)
# summary(Fpari1.out)
# options(digits=3)

## Fit a PIAR(2) model with seasonal intercepts.
out.piar <- fit.piar(wts=lgergnp, detcomp=detcomp, p=2)
summary(out.piar, digits=1)

## Test for a single unit root in a PAR(2) model with seasonal intercepts.
out.LR <- LRurpar.test(wts=lgergnp, detcomp=detcomp, p=2)
options(digits=1)
summary(out.LR)
options(digits=7)

plotpdiff <- function(x){
  if (!inherits(x,"fit.piartsm"))
    stop("\n Object is not of class 'fit.piartsm'.\n")

  opar <- par(las=1)
  layout(matrix(c(1, 1, 2, 3), 2 , 2, byrow=TRUE))
  plot(x@pdiff.data, main="Periodically differenced data", ylab="", xlab="")
  bbplot(x@pdiff.data)
  monthplot(x@pdiff.data, ylab="")
  par(opar)
}

################################################
#### Copied bbplot (from uroot package)
################################################


bbplot <- function(wts, colour=c("SlateBlue","SeaGreen","red","magenta"))
{
  s <- frequency(wts)
  if(s==4){
    nl <- 4; np <- 1; fr <- 2
    snames <- c("Qrt1", "Qrt2", "Qrt3", "Qrt4")
  }
  else if(s==12){
    nl <- 3; np <- fr <- 4
    snames <- month.abb
  }
  else{
    if(identical(c(s/2 - as.integer(s/2)), 0)){
      nl <- 4; np <- s/nl
    }
    else{
      np <- floor((s+1)/4); nl <- c(rep(4, np-1), s/np+1)
    }
  }

  Mseas <- Msts(wts)

  aux <- Mseas[nrow(Mseas),]
  labaux <- c(na.omit(aux), Mseas[(nrow(Mseas)-1),which(is.na(aux))])

  xlim <- c(start(wts)[1], end(wts)[1]+1.5)
  ylim <- range(wts, na.rm=TRUE)
  aux1 <- seq(1,s,nl); aux2 <- seq(nl,s,nl)

  if(s==4)
    opar <- par(mar=c(3,3.5,2,2), las=1)
  if(s==12)
    opar <- par(mfrow=c(fr/2, fr/2), mar=c(3,3.5,2,2), las=1)
  for(i in 1:np){
    ref <- aux1[i]:aux2[i]
    ts.plot(ts(Mseas[,ref], start=start(wts)[1]), xlab="", ylab="",
      xlim=xlim, ylim=ylim , col=colour)

    #text(xlim[2]-0.2, as.matrix(Mseas[,ref])[nrow(Mseas),], month.abb[ref])
    text(xlim[2]-0.2, labaux[ref], snames[ref], col=colour)
  }
  par(opar)
}

################################################
#### Auxilliary function Msts (from uroot package)
################################################


Msts <- function(wts)  ##~ hacer que trate a las columnas como ts, ts.union.
{
  s <- frequency(wts)
  seas.data <- split(wts, cycle(wts))
  Mseas <- matrix(NA, nrow=ceiling(length(wts)/s), ncol=s)
  ref1 <- c(rep(2, start(wts)[2]-1), rep(1, s-start(wts)[2]+1))
  ref2 <- c(rep(0, end(wts)[2]), rep(1, s-end(wts)[2]))
  for(i in 1:s)
    Mseas[ref1[i]:(nrow(Mseas)-ref2[i]),i] <- seas.data[[i]]  # unlist(seas.data[[i]])

  ynames <- as.integer(time(wts))
  if(s==4)
    snames <- c("Qtr1", "Qtr2", "Qtr3", "Qtr4")
  else if(s==12)
    snames <- month.abb
  else
    snames <- paste("Seas", 1:s, sep="")

  Mseas <- matrix(Mseas, nrow=nrow(Mseas), ncol=ncol(Mseas),
           dimnames=list(as.character(ynames[1]:ynames[length(ynames)]), snames))

#  for(i in 1:ncol(Mseas))
#    Mseas[,i] <- ts(Mseas[,i], frequency=1, start=start(wts))
#  as.matrix(Mseas)
  Mseas
}

################################################
#### Deprecated bbplot (old code)
################################################

## Ver hacer metodo hasta obtener seas.data.
## ver usar cbind.ts.
# bbplot <- function(wts)
# {
#   colour <- c("SlateBlue","SeaGreen","red","magenta")
#   seas.data <- split(wts, cycle(wts))
# 
#   t0 <- c(rep(1, start(wts)[2]-1), rep(0, frequency(wts)-(start(wts)[2]-1)))
#   for(i in 1:frequency(wts))
#     assign(paste("season", i, sep=""), ts(seas.data[[i]], frequency=1, start=start(wts)[1]+t0[i]))
# 
#   if(frequency(wts) == 4){
#     seas.labels <- c("Q1","Q2","Q3","Q4")
#     seas.data <- list(season1, season2, season3, season4)
#     opar <- par(las=1)
#     ts.plot(season1, season2, season3, season4, lty=c(1,2,3,4), xlab="", ylab="",
#             xlim=c(start(wts)[1], end(wts)[1]+2.5)) ##~ col=colour
#     par(opar)
#     for(i in 1:4)
#       text(end(seas.data[[i]])[1]+2, seas.data[[i]][length(seas.data[[i]])], seas.labels[i])
#       ##~ , col = colour[i])
#   }
# 
#   if(frequency(wts) == 12){
#     seas.data <- list(season1, season2, season3, season4, season5, season6,
#                       season7, season8, season9, season10, season11, season12)
#     xlim <- c(start(wts)[1], end(wts)[1]+1.5); ylim <- c(min(wts), max(wts))
# 
#     opar <- par(mfrow=c(2,2), las=1)
#     ts.plot(season1, season2, season3, lty=c(1,2,3), xlab="", ylab="", xlim=xlim, ylim=ylim) ##~ col=colour)
#     for(i in 1:3)
#       text(end(seas.data[[i]])[1]+1, seas.data[[i]][length(seas.data[[i]])], month.abb[i]) ##~ , col =  colour[i])
#     ts.plot(season4, season5, season6, lty=c(1,2,3), xlab="", ylab="", xlim=xlim, ylim=ylim) ##~ col=colour)
#     for(i in 4:6)
#       text(end(seas.data[[i]])[1]+1, seas.data[[i]][length(seas.data[[i]])], month.abb[i]) ##~ , col = colour[i])
#     ts.plot(season7, season8, season9, lty=c(1,2,3), xlab="", ylab="", xlim=xlim, ylim=ylim) ##~ col=colour)
#     for(i in 7:9)
#       text(end(seas.data[[i]])[1]+1, seas.data[[i]][length(seas.data[[i]])], month.abb[i]) ##~ , col = colour[i])
#     ts.plot(season10, season11, season12, lty=c(1,2,3), xlab="", ylab="", xlim=xlim, ylim=ylim) ##~ col=colour)
#     for(i in 10:12)
#       text(end(seas.data[[i]])[1]+1, seas.data[[i]][length(seas.data[[i]])], month.abb[i]) ##~ , col = colour[i])
#     par(opar)
#   }
# }

\documentclass{article}
%\VignetteIndexEntry{partsm vignette}
\usepackage[round]{natbib}
\usepackage{hyperref}
\bibliographystyle{agsm}

\newcommand{\pkg}[1]{{\normalfont\fontseries{b}\selectfont #1}}
\newcommand{\proglang}[1]{\textsf{#1}}
\let\code=\texttt
\newcommand{\file}[1]{`\textsf{#1}'}
\newcommand{\email}[1]{\href{mailto:#1}{\texttt{#1}}}
\pdfstringdefDisableCommands{\def\email#1{#1}\def\pkg#1{#1}\def\proglang#1{#1}}

\author{Javier L\'opez-de-Lacalle%
  \thanks{I acknowledge Matthieu Stigler's contribution for the upgrade and maintenance of the package.}\\
  Universidad del Pa\'is Vasco\\
  \texttt{javlacalle@yahoo.es}}
\title{Periodic Autoregressive Time Series Models in \proglang{R}: The \pkg{partsm} Package.}
\date{April 2012}

\begin{document}
\maketitle

\begin{abstract}
This introduction to the \proglang{R} package \pkg{partsm} is a (slightly)
modified version of \cite{Lopez-de-Lacalle:05}.

It is well-known that some of the macroeconomic time series display stochastic trends, moreover, when working with seasonally observed data stochastic seasonal cycles may exist as well. When these components, trend and seasonality, do not evolve independently, traditional differencing filters may not be suitable.
According to periodic autoregressive time series models, a seasonally varying autoregressive parameters and a periodic differencing filter are proposed for that case.

This paper focuses on practical issues
showing the use of the \pkg{partsm} \proglang{R}-package. This package allows the user to
check for periodicity in the data, fit a periodic autoregressive model of order p, PAR(p), select the periodic autoregressive lag order parameter, test for periodic integration, fit a periodically integrated autoregressive model up to order 2, PIAR, as well as to perform out-of-sample forecasts.
\end{abstract}

\noindent\textit{Keywords}: Time series, PAR models, periodic integration, \proglang{R}

\section[Introduction]{Introduction}

It is well-known that some of the macroeconomic time series display stochastic trends, moreover, when working with seasonally observed data stochastic seasonal cycles may exist as well. When these components, trend and seasonality, do not evolve independently, traditional differencing filters may not be suitable.
According to periodic autoregressive time series models, a seasonally varying autoregressive parameters and a periodic differencing filter are proposed for that case.
For a review of this literature see \citet{Franses:96}, \citet{Franses-Paap:04}, and references therein.

This paper focuses on practical issues 
showing the use of the \pkg{partsm} \proglang{R}-package. This package allows the user to check for periodicity in the data, fit a periodic autoregressive model of order p, PAR(p), select the periodic autoregressive lag order parameter, test for periodic integration, fit a periodically integrated autoregressive model up to order 2, PIAR, as well as to perform out-of-sample forecasts.

The remaining of the paper is organized as follows. Section \ref{Sreview} briefly reviews the statistical issues the \pkg{partsm} \proglang{R}-package is concerned, namely periodic autoregressive models and periodic integration. Section \ref{Sdesc} describes the package. Section \ref{Sexample} puts into practice the tools implemented in the package showing how to use them and interpreting the results accordingly. 
%Some known bugs are mentioned in Section \ref{Sbugs}.

\section[Theoretical overview]{Theoretical overview} \label{Sreview}

This section reviews the main theoretical concerns entailed in the process of fitting periodic models and testing for a unit root in PAR models. To have a further insight into this models see \citet{Franses:96}, \citet{Franses-Paap:04}, and references therein. PAR models are intended for seasonally observed data, particularly quarterly and monthly data. To save space, hereafter we will consider quarterly data, $S=4$.

\subsection[Notation and representation of PAR models]{Notation and representation of PAR models}

The \textit{univariate representation} of a PAR(p) model is as follows,

\begin{equation}
\label{PAR}
y_t = \phi_{1s} y_{t-1} + ... + \phi_{ps} y_{t-p} + \epsilon_t, \quad \epsilon_t \sim iid (0,1),
\end{equation}
%
for $s=1,...,4$, for $t=1,2,...,n$, where $n$ is the number of observations. Hence, the autoregressive parameters vary with the season for each lag. 

Since a PAR(p) entails four different AR(p) models, one for each season, it is useful to rewrite (\ref{PAR}) as the \textit{multivariate representation} or \textit{vector of quarters representation}.
%
\begin{equation}         
\label{PARVQ}
\Phi_0\,Y_{s,T} = \Phi_1\,Y_{s,T-1} + ... + \Phi_P\,Y_{s,T-P} + \epsilon_T, \quad \epsilon_T \sim iid (0,1),
\end{equation}
%
where $\Phi_0, \Phi_1,...,\Phi_P$ are $(4\times4)$ parameter matrices with the parameters in (\ref{PAR}) as follows:
%
\begin{eqnarray*}
\Phi_0\,(i,j) &=& 1 \quad if \quad i=j \\
              &=& 0 \quad if \quad j > i \\
              &=& -\phi_{i-j,i} \quad if \quad j < y \\
\Phi_k\,(i,j) &=& \phi_{i+4k-j,i},
\end{eqnarray*}
%
for $i,j=1,2,3,4$ and $k=1,2,...,P$. The univariate model of order $p$ turns into a multivariate model of order $P=1+[(p-1)/4]$, where $[x]$ is the integer part of $x$.

Notice that in (\ref{PAR}) each lag leads to previous observations in the seasonally observed data, whereas in (\ref{PARVQ}) lags have effect on the annually observed data in each season. That is, $y_{t-1}$ is the observation immediately previous to $y_t$, and $Y_{s,T-1}$ is the observation in season $s$ previous to the year $T$.

Finally, if the roots of the factorized AR(p) model related to each season are all real values, the PAR(p) model can be represented as
%
\begin{eqnarray} 
y_t-\alpha_s\,y_{t-1} &=& \beta_{1s}\,(y_{t-1} - \alpha_{s-1}\,y_{t-2}) + ... + \\ \nonumber
&+& \beta_{(p-1)s}\,(y_{t-(p-1)} - \alpha_{s-(p-1)}\,y_{t-p}) + \epsilon_t, \quad \epsilon_t \sim iid (0,1).
\end{eqnarray}
%
called the \textit{periodically differenced form of} (\ref{PAR}).

\subsection[Periodic integration]{Periodic integration} \label{Sreview.pi}

Basically, a time series with a unit root, $y_t$, is periodically integrated if there exist 
some $\alpha_s$ for $s=1,2,...,4$, in such a way that the transformed series $(1-\alpha_s\,B)\,y_t$ does not contain a unit root, where $B$ is the backward operator. 
The definition of \citet{Franses:96} is transcribed below.
%
\begin{quotation}
A quarterly time series $y_t$ is said to be \textit{periodically integrated of order 1} [PI] when the differencing filter $(1-\alpha_s\,B)$ is needed to remove the stochastic trend from $y_t$, where $\alpha_s$ are seasonally varying parameters with the property that $\alpha_1\alpha_2\alpha_3\alpha_4=1$ and $\alpha_s \neq \alpha$ for all $s=1,2,3,4$.
\end{quotation}

At present, the package \pkg{partsm} only allow to estimate periodically integrated autoregressive models up to order 2\footnote{PAR models use to be more parsimonious models and a first or second order model may be suitable for the data. In \citet{Franses:96}, only one out of the eleven series analysed required a higher order PAR model.}. Taking the periodically differenced representation, the following model can be estimated by non-linear least squares.

\begin{equation}    
\label{PIAR2}
y_t - \alpha_s y_{t-1} = \beta_s (y_{t-1} - \alpha_{s-1} y_{t-2}) + \epsilon_t, \quad \epsilon_t \sim iid (0,1),
\end{equation}
%
under the non-linear restriction $\prod_{s=1}^{4} \alpha_s = 1$ for $s=1,...,4$. Obviously, for a first order PIAR process $\beta$ parameters are equal to zero. This model can be estimated by non-linear least squares.

Note that the restriction above is fulfilled in these particular cases, among others. When $\alpha_s=1$ for $s=1,2,3,4$, and $\alpha_s=-1$ for $s=1,2,3,4$. 
The former case give rise to the $(1-L)$ differencing filter, whereas the latter entails the $(1+L)$ differencing filter. 
%
Therefore, the restriction may involve the long run unit root 1, or the seasonal unit root -1, or neither of them.

When the hypothesis above cannot be rejected it is said that the process is a \textit{PAR process for a I(1) times series}, PARI. Otherwise, the PAR model is known as a \textit{periodically integrated AR model}, PIAR, and the periodic differencing filter is obtained from the $\alpha_s$ estimates in equation (\ref{PIAR2}).

In Section \ref{Sexample} we will see how to carry out this analysis following a common strategy for the empirical analysis. First, we will take a look at the package we will use for it.

\section[The partsm package]{The \pkg{partsm} package} \label{Sdesc}

\subsection[Description]{Description}

This section documents the \pkg{partsm} package version 1.0 built on the \proglang{R} language and environment for statistical computing and graphics \citep{Chambers:98, Rproject}. The package performs some of the relevant tests and models for fitting periodic autoregressive time series model introduced in the previous section.

The package is distributed under the General Public License [GPL] version 2 or newer. The terms of this license are in a file called COPYING which you should receive with \proglang{R}.  After reading the terms of the license, the user will understand that the datasets and software are provided in good faith, but the author does not warrant their accuracy nor can be held responsible for the consequences of their use. %It is the author's understanding that the dataset files \file{partsm/data/*.rda} are not copyright.

The source code and binaries of the package are available at CRAN (\url{https://cran.r-project.org/}). To add it as a package copy the binaries in the subdirectory \file{library} where \proglang{R} is installed\footnote{Type \code{R.home()} in an \proglang{R}-console to find out the home directory.}. Alternatively, download the package source and install it with \code{R CMD INSTALL partsm$\_$1.0.tar.gz}. To install it from an \proglang{R}-console type \code{install.packages("partsm")} and select a mirror near to your location.

\subsection[Classes and methods]{Classes and methods}
% basado en S4 classes (citar Chambers ver libro Venables Ripley 2002) containing useful information for some methods, show, summary, and functions.

To store the relevant information provided by the implemented functions, the following classes are defined: \code{fit.partsm} and \code{fit.piartsm} contain the information from a fitted AR, PAR, or PIAR model; \code{Ftest.partsm} and \code{LRur.partsm} store the information from the statistical tests in the package; and \code{pred.piartsm} contains information on a PIAR model forecasts. For more information, see the standard help pages of the package\footnote{A \file{pdf} version is available in the \file{partsm/doc} subdirectory.}

Likewise, some methods are defined for objects of the classes cited above. To display the information in each object, the \code{show} method displays the main results in a friendly format, whereas \code{summary} extends the information provided by \code{show}. To build the matrices for the multivariate representation, the \code{PAR.MVrepr} method can be applied on objects of class \code{fit.partsm} or \code{fit.piartsm}.


%%% Comment Matthieu: removed as Rcmdr not supported anymore
% \subsection[Interface via the Rcmdr]{Interface via the \pkg{Rcmdr}}
% 
% An easy to use interface can be added via the \pkg{Rcmdr} package\footnote{The \pkg{partsm} add-in has been checked for the version 1.0-2 of \pkg{Rcmdr}.} \citep{Rcmdr}. For further information on the \pkg{Rcmdr} see the documentation provided with it in the \file{Rcmdr/doc} subdirectory \citep{Fox:05}.
% 
% To install the \pkg{partsm} add-in for the \pkg{Rcmdr} copy the file \file{partsm/R-cmdr/Rcmdr-partsm.R} in the \file{Rcmdr/etc} subdirectory. This file contains functions for launching the corresponding dialog boxes. To add the menus, copy the text in the file \file{partsm/R-cmdr/Rcmdr-menus.txt} in the desired place inside the file \file{Rcmdr/etc/Rcmdr-menus.txt}, for example after the \code{Tools} menu\footnote{After a line similar to `\code{item topMenu cascade "Tools" toolsMenu.}'}.
% 
% For the package to be available, the item \code{Load partsm} must be first clicked in the \code{partsm} menu. In this version, the object to which the functions can be applied must be of class \code{ts}, that is, time series. However, the \pkg{Rcmdr} works with data frames objects. The dialog boxes as well as the functions for \code{partsm} automatically detect all the \code{ts} objects in the working space, hence, there is no need to have an active data set available. In addition, the data in \pkg{partsm} can be loaded from the \code{Data - Data in packages - Read data set from an attached package} menu, ignoring the error message for the functions regarding the \code{partsm} menu.
% 
% Finally, the user must bear in mind that, in this version, the interface does not allow to apply all the functions and all the arguments either.

\section[Examples and applications]{Examples and applications} \label{Sexample}

This Section complements the standard help pages provided with the package carrying out an entire application. The use and interpretation of the functions implemented in the package is described following the same steps as in a real application, devoting a subsection for each one of them. 

It is worth describing first one of the arguments that will appear in most of the functions. The argument called \code{detcomp} refers to the deterministic components to include in the model. Three types of regressors can be included: regular deterministic components, seasonal deterministic components, and any regressor variable previously defined by the user. This argument must be a list object with the following elements:
\begin{itemize}
\item \code{regular=c(0,0,0)}, if the first and/or second element are set equal to 1, it indicates that an intercept, and/or linear trend, respectively, are included. The third element in \code{regular} is a vector indicating which seasonal dummies should be included. If no seasonal dummies are desired it must be set equal to zero. For example, \code{regular=c(1,0,c(1,2,3))} would include an intercept, no trend, and the first three seasonal dummies.
\item \code{seasonal=c(0,0)}, if an element is set equal to 1, it indicates that seasonal intercepts, and/or seasonal trends, respectively, are included in the model.
\item \code{regvar=0}, if none regressor variables are considered, this object must be set equal to zero, otherwise, the names of a matrix object previously defined with the desired regressors by columns should be indicated.
\end{itemize}

We will take for the examples below the logarithms of the Real Gross Domestic Product in Germany. This time series, along with the others provided with the package, is analysed in \citet{Franses:96}. Let's start loading the package and the data.
%
<<>>=
library(partsm)
data("gergnp")
lgergnp <- log(gergnp, base=exp(1))
@

\subsection[Model order selection]{Model order selection}

The first issue we will deal with is the selection of the order for the periodic autoregressive model. The function \code{Fnextp.test} performs a test for the significance of prospective lag parameters of order $p+1$ in an AR(p) or PAR(p) model. It is performed as an $F$-statistic that sets the parameters of order $p+1$ equal to zero. We will use this statistic and the Akaike's [AIC] and Schwarz's [BIC] information criteria to select the autoregressive order. The code below computes these statistics for PAR models of order ranged between 1 and 4.

The function \code{fit.ar.par} fits a PAR model with seasonal intercepts and stores the results in the \code{lmpar} object of class \code{fit.partsm}. Then, the AIC and BIC statistics are computed by means of the function \code{AIC} available in the \pkg{base} \proglang{R}-package. 

Finally, the null hypothesis $\phi_{(p+1),s}=0$ is checked with \code{Fnextp.test}. The $F$-statistics and the corresponding $p$-values are stored in \code{Fnextp} and \code{Fpval}, respectively. These statistics are computed for PAR models with seasonal intercepts. 

<<>>=
detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
aic <- bic <- Fnextp <- Fpval <- rep(NA, 4)
for(p in 1:4){
  lmpar <- fit.ar.par(wts=lgergnp, detcomp=detcomp, type="PAR", p=p)
  aic[p] <- AIC(lmpar@lm.par, k=2)
  bic[p] <- AIC(lmpar@lm.par, k=log(length(residuals(lmpar@lm.par))))
  Fout <- Fnextp.test(wts=lgergnp, detcomp=detcomp, p=p, type="PAR")
  Fnextp[p] <- Fout@Fstat
  Fpval[p] <- Fout@pval
}
@

To save space, the results of the code 
are reported in Table \ref{TselecP}. PAR parameters of order 2 are significant, whereas, lag parameters up to order 4th appear to be equal to zero. Furthermore, the AIC and BIC criteria reach the lowest value for a second order model. Therefore, we will analyse the properties of a second order PAR model with seasonal intercepts 
for the \code{lgergnp} time series.

\begin{table}[ht]
\centering \caption{Periodic autoregressive order selection}
\label{TselecP}
\begin{tabular}{llcccc} \\
\hline \hline
Criterion && \multicolumn{4}{c}{Periodic autoregressive order} \\
\cline{3-6} && 1 & 2 & 3 & 4 \\
\hline      
AIC && $-661.60$ & $-680.89$ & $-669.84$ & $-661.54$ \\
BIC && $-636.30$ & $-644.44$ & $-622.31$ & $-603.00$ \\   
$F(\phi_{p+1,s}=0)$ && $8.54$ & $0.80$ & $1.35$ & $2.91$ \\
\multicolumn{1}{c}{$p$-value} && $0.00$ & $0.53$ & $0.26$ & $0.03$ \\
\hline \hline
\end{tabular}
\end{table}

\subsection[Test for periodic variation in the autoregressive parameters]{Test for periodic variation in the autoregressive parameters}

Once a PAR model has been defined, we can check for periodicity in the autoregressive parameters of the model. Following the notation in (\ref{PAR}), the function \code{Fpar.test} performs an $F$-test for the null hypothesis of non-periodicity, $\phi_{is}=\phi_i$ for $s=1,2,...,4$ and $i=1,2,...,p$.

When the null hypothesis is imposed an AR(p) is estimated, whereas in the alternative a PAR(p) model is fitted. Then, based on the residual sum of squares of each model, the $F$-statistic is computed. When four seasonal intercepts are included the statistic follows an $F$-distribution with (3\,p, n-(4+4\,p)) degrees of freedom, where $n$ is the number of observations.
   
<<>>=
dcsi <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
out.Fparsi  <- Fpar.test(wts=lgergnp, detcomp=dcsi, p=2)
show(out.Fparsi)
dcsit <- list(regular=c(0,0,0), seasonal=c(1,1), regvar=0)
out.Fparsit <- Fpar.test(wts=lgergnp, detcomp=dcsit, p=2)
show(out.Fparsit)
@
    
The results of the code above show that periodicity is not rejected, therefore, the test corroborates that a periodic model fits better to the data rather than an AR model, which is constrained to seasonally constant parameters. With regard to the so-called deterministic components, the reader can check that seasonal trends can be left out in the PAR(2) model. For it, type \code{summary(out.Fparsit)} and check the $t$-statistics and $p$-values in the model fitted for the alternative hypothesis for the parameters denoted as \code{MDT..SeasTrnd.1:4}.

\subsection[Diagnostic for the fitted PAR model]{Diagnostic for the fitted PAR model}

The function \code{Fsh.test} performs an $F$-statistic to check whether seasonal heteroskedasticity exist in the residuals of the fitted model, in this case, a PAR(2) model with seasonal intercepts.

<<>>=
par2 <- fit.ar.par(wts=lgergnp, type="PAR", p=2, detcomp=detcomp)
Fsh.out <- Fsh.test(res=residuals(par2@lm.par), s=frequency(lgergnp))
show(Fsh.out)
@

Results in the code above show that seasonal heteroskedasticity is rejected at the 5\% significance level. This analysis is very limited to validate the model and the user is suggested to carry out complementary tests such as Ljung-Box test for autocorrelation, \code{Box.test}; Jarque-Bera test for normality, \code{jarque.bera.test}; or \code{runs.test} for randomness\footnote{The first function is available in the \pkg{base} package provided with the standard distribution of \proglang{R}. The other functions can be found in the package called \pkg{tseries}.}. Nevertheless, this analysis is beyond the scope of this paper and we will move on to analyze some properties of the selected model for the \code{lgergnp} time series.

\subsection[Eigenvalues of the estimated Gamma equiv Phi_0^{-1}Phi_1 matrix]{Eigenvalues of the estimated $\Gamma \equiv \Phi_0^{-1}\Phi_1$ matrix}

Taking the multivariate representation, as in equation (\ref{PARVQ}), we can get the eigenvalues of the estimated $\Gamma \equiv \Phi_0^{-1}\Phi_1$ matrix. These eigenvalues provide a first 
view on the prospective unit roots.  

The function \code{PAR.MVrepr} applied on the \code{out.par} object of class \code{fit.partsm} below, shows the matrices defined is Section \ref{Sreview} for the multivariate representation and some complementary information. 

<<>>=
out.par <- fit.ar.par(wts=lgergnp, type="PAR", detcomp=detcomp, p=2)
out.MV <- PAR.MVrepr(out.par)
out.MV
@

There is only one eigen value of the $\Gamma \equiv \Phi_0^{-1}\Phi_1$ matrix close to 1, hence, it seems that there is a single unit root . Furthermore, since this value

There are not complex eigen values in the $\Gamma \equiv \Phi_0^{-1}\Phi_1$ matrix. It seems to exist a single unit root in the model. Furthermore, the eigenvalue close to 1 suggests that it may exist the long run unit root 1. We will take again a look at this representation and will discuss the remaining of the output of the function.

\subsection[Test for a single unit root]{Test for a single unit root}

The next step is to carry out formal tests to check whether a unit root exists. As it has been mention in Section \ref{Sreview.pi}, a PAR model contains a unit root if $\prod_{s=1}^{4} \alpha_s = 1$. We have also noticed that this restriction is satisfied in two particular cases, when $\alpha_1$, $\alpha_2$, $\alpha_3$, and $\alpha_4$ are either 1 or -1. In these cases the periodic filter collapses into 
the filter related to the long run unit root 1, $(1-B)$, and to the seasonal unit root -1, $(1+B)$, respectively, and the model is known as a PAR process for a I(1) time series, PARI.

In other cases in which the restriction $\alpha_1\alpha_2\alpha_3\alpha_4=1$ 
is fulfilled, the series is said to be guided by a periodically integrated AR process, PIAR. Then, the periodically differencing filter is $(1-\alpha_s\,B)$ for $s=1,2,...,4$, where $\alpha_s$ are inferred from the data by fitting the model (\ref{PIAR2}).

Taking into account these remarks, and as \citet{Franses:96} suggests, it is a wise analysis to test first for the non-linear restriction $\prod_{s=1}^4\,\alpha_s=1$. If this hypothesis cannot be rejected the time series contains a unit root. To see whether the process is a PARI process with the long run seasonal unit root 1, or the seasonal unit root -1, or a PIAR process, the following hypothesis can be checked\footnote{Note that only three restrictions are checked, since $\alpha_s=1 \,\mbox{or} -1$ just for $s=1,2,3$ entails either $\alpha_4=1$ or $\alpha_4=-1$.},
%
$$H0: \alpha_s = 1 \quad \mbox{for}\,\, s=1,2,3,$$
$$H0: \alpha_s = -1 \quad \mbox{for}\,\, s=1,2,3.$$ 

The function \code{LRurpar.test} performs a likelihood ratio test for the first step we desire to check. A one-side statistic is also computed as $sign(\prod_{s=1}^{4} \alpha_s - 1) * LR^{1/2}$, where $\hat{\alpha}$ are the periodic differencing filter parameters estimated under the alternative. According to this statistics, the results of the code shows that it cannot be rejected a unit root.

<<>>=
out.LR <- LRurpar.test(wts=lgergnp, detcomp=detcomp, p=2)
show(out.LR)
@

Now it is worth checking whether $\alpha_s$ for $s=1,2,3$, can be either $1$ or $-1$. The corresponding $F$-statistic for the PAR(2) model with seasonal intercepts is computed by \code{Fpari1.out}. The first hypothesis is considered when \code{type="PARI1"} is selected. According to the results below, this hypothesis, i.e. the long run unit root 1 is rejected.

<<>>=
Fpari1.out <- Fpari.piar.test(wts=lgergnp, detcomp=detcomp, p=2, type="PARI1")
show(Fpari1.out)
@

The reader can check that the seasonal unit root -1 is rejected as well, as we could expect allowing for the eigen values of the estimated matrix $\Phi0^{-1}\,\Phi_1$. For it, just select \code{type="PARI-1"}.

\subsection[Autocorrelation function for several transformations of the original data]{Autocorrelation function for several transformations of the original data}

In this subsection we will take a look at the nonperiodic autocorrelation function. The function \code{acf.ext1} computes the ACF for several transformations of the data\footnote{See the standard help pages to see what transformations are considered.}. Table \ref{Tacf} shows the ACF of the original data, the first differenced series and the periodically differenced series, removing four seasonal intercepts in the last two cases. According to the results is sections above other transformations are not worth considering. 

\begin{table}[ht]
\begin{minipage}{\textwidth}
\centering \caption{Estimated autocorrelation function for several transformations of the original data}
\label{Tacf}
\begin{tabular}{lrlrlrl} \\
\hline \hline  
    & \multicolumn{6}{c}{Transformations of the original data, $y_t$
\footnote{ The following transformations are considered:
$y_t$: Original series;
$\Delta\,y_t-\hat{\delta_s}$: residuals of the first differences on four seasonal dummy variables;
$(1-\hat{\alpha}_s\,B)\,y_t-\hat{\delta_s}$: residuals of the periodic differences on four seasonal dummy variables.
}
} \\ \cline{2-7}
Lag & \multicolumn{2}{c}{$y_t$} & \multicolumn{2}{c}{$\Delta\,y_t-\hat{\delta_s}$} 
    & \multicolumn{2}{c}{$(1-\alpha_s\,B)\,y_t-\hat{\delta_s}$} \\
\hline
0 & $1.00$ & *** &  $1.00$  & *** & $1.00$  & *** \\
1 & $0.95$ & *** &  $-0.15$ &   . & $-0.12$ &     \\
2 & $0.90$ & *** &  $-0.47$ & *** & $-0.20$ &   * \\
3 & $0.89$ & *** &  $-0.08$ &     & $0.00$  &     \\
4 & $0.89$ & *** &  $0.71$  & *** & $0.37$  & *** \\
5 & $0.84$ & *** &  $-0.15$ &   . & $-0.17$ &   . \\
6 & $0.80$ & *** &  $-0.42$ & *** & $-0.10$ &     \\
7 & $0.79$ & *** &  $-0.05$ &     & $0.06$  &     \\
8 & $0.78$ & *** &  $0.54$  & *** & $0.02$  &     \\
9 & $0.74$ & *** &  $-0.08$ &     & $-0.07$ &     \\
10 & $0.70$ & *** & $-0.40$ & *** & $-0.07$ &     \\
11 & $0.69$ & *** & $-0.06$ &     & $0.03$  &     \\
12 & $0.68$ & *** & $0.49$  & *** & $0.03$  &     \\
\textit{s.e. \footnote{Standard error calculated as $1/n^{1/2}$.}} 
           & $\mathit{0.09}$ && $\mathit{0.09}$ && $\mathit{0.09}$ \\
\hline \hline
\end{tabular}
\footnote[0]{Significance codes:  0 `***' 0.001 `**' 0.01 `*' 0.05 `.' 0.1 ` ' 1.}
\end{minipage}
\end{table}

The ACF of the original series shows a clearly long-memory behaviour, since autocorrelations are significant for high orders. It can also be observed that the periodically differenced series performs better than the first differencing filter, since the latter does not remove the stochastic behaviour.

The periodically differenced series and the corresponding seasonal path are displayed by \code{plotpdiff}. This function applies on object of class \code{fit.piartsm} as \code{out.piar} built above. Figure \ref{Fpddata} shows that the periodic differencing filter success in removing the stochastic behaviour, since the seasonal paths (at the bottom of the Figure) are parallel to each other and do not display trending behaviour.

\subsection[Time varying impact of accumulation of shocks]{Time varying impact of accumulation of shocks} 

The $\Phi_0$ and $\Phi_1$ matrices can be used to compute the impact of accumulation of the shocks $\epsilon_t$ defined as $\Gamma\,\Phi_0^{-1}$, where $\Gamma$ is $\Phi_0^{-1} \Phi_0$. That row in which the values of the impact matrix are the highest, entails that the corresponding season undergoes more severe impacts from the accumulation of all shocks. Hence, it is more likely to display fluctuations in the stochastic trend. Likewise, the column with the highest values is related to the season that has the largest long-run impact. Put in other words, the impact matrix allow the practitioner to get an idea about how the stochastic trend and the seasonal fluctuations are related.

To derive those matrices, the model (\ref{PIAR2}) is estimated with \code{fit.piar} is used. This function requires some values to initialize the non-linear estimator. By default, initial values are computed for the non-linear model. However, in this version there may be cases in which the estimates do not converge, giving an error message. In this case, a numeric vector with initial values guessed by the user can be included. The code below let \code{fit.piar} to compute initial values, hence, there is no need to include a vector called \code{initvalues} as an argument.

<<>>=
out.piar <- fit.piar(wts=lgergnp, detcomp=detcomp, p=2)
out.MV <- PAR.MVrepr(out.piar)
out.MV
@
%<<pddata, fig=TRUE, echo=FALSE, height=4.5, width=5>>=
\begin{figure}[ht]
\begin{center}
\caption{\label{Fpddata} Periodically differenced data and seasonal paths}
<<pdiffplot, fig=TRUE, echo=FALSE>>=
plotpdiff(out.piar)
@
\end{center}
\end{figure}

For the series \code{lgergnp}, the row with the highest values is the fourth column. This means that the stochastic trend is more likely to undergo changes in the fourth quarter. Reading the impact matrix by columns, the one with the highest is the third column, hence, the third quarter is more sensitive to changes in the stochastic trend.

Obviously, the results above also show that the PIAR model contains a root that is exactly equal to 1 because that is precisely the restriction imposed in the parameters of the model. The other slots of the output not cited here are matrices for internal use when making forecast in a PIAR model.

\subsection[Out-of-sample forecasts]{Out-of-sample forecasts}

The function \code{predictpiar} makes prediction based on PIAR model of order up to 2. By default seasonal intercepts are included. This function computes one-year-ahead forecasting on the basis of the multivariate representation. The forecast for the year $T+$ is $Y_{T+1} = \Phi_0^{-1}\,\mu + \Phi_0^{-1}\,\Phi_1\,Y_T$. The confidence intervals are computed deriving the multivariate moving averages representation from the matrices for the multivariate PIAR model. 

The code below performs 24 ahead forecasts in the PIAR(2) model. For programming convenience, the number of forecasts, \code{hpred}, must be a multiple of the periodicity of the data. The output of this function provides an object of class \code{pred.piartsm} containing the forecast, the standard errors, the upper and lower 95 per cent confidence bound, as well as the input, i.e., the original data, the order of the model, and the number of predictions.

<<>>=
out.pred <- predictpiar(wts=lgergnp, p=2, hpred=24)
show(out.pred)
@

Remember that the data are scaled in logarithms, hence, for the results to be interpreted, the original scale must be set. The code below makes this task and plots a graphic with the forecast and confidence intervals displayed in Figure \ref{Fpred}.

<<>>=    
out.pred@wts <- exp(1)^out.pred@wts
out.pred@fcast <- exp(1)^out.pred@fcast
out.pred@ucb <- exp(1)^out.pred@ucb
out.pred@lcb <- exp(1)^out.pred@lcb
plotpredpiar(out.pred)
@

% <<predplot, fig=TRUE, echo=FALSE, height=4.5, width=5>>=
\begin{figure}[ht]
\begin{center}
\caption{\label{Fpred} Forecast and confidence intervals}
<<predplot, fig=TRUE, echo=FALSE>>=
plotpredpiar(out.pred)
@
\end{center}
\end{figure}

%\section[Known bugs]{Known bugs} \label{Sbugs}
%\begin{itemize}
%\item \code{fit.piar} function may give an error message similar to \code{Error in nls(form.rpar, start = nlsinit, trace = FALSE) : step factor 0.000488281 reduced below} $\quad$ \code{'minFactor' of 0.000976562}. The reason for it might be that the initial values selected for performing non-linear least squares are too far from converge. Other alternatives (not available at user level) should be considered for it.
%\end{itemize}

%If you experiment any bug or pitfalls using \pkg{partsm}, or have some improvement or comment to suggest, please report it to \email{javlacalle@yahoo.es}.

%\section[Concluding remarks]{Concluding remarks} \label{Sconcl}

\clearpage  % tambien para meter tablas, figuras dentro de su seccion
\bibliography{partsm}

\end{document}

\name{fit.ar.par}
 \alias{fit.ar.par}
  \title{Fit an Autoregressive or Periodic Autoregressive Model}

  \description{
    This function fits either an autoregressive (AR) or a periodic autoregressive (PAR) model and extract the
    estimates for the autoregressive or periodic autoregressive coefficients.
  }

  \usage{
    fit.ar.par (wts, type, detcomp, p)
  }

  \arguments{
    \item{wts}{a univariate time series object.}
    \item{type}{A character string indicating whether the model to fit is an autoregressive model,
      \code{"AR"}, or a periodic autoregressive model, \code{"PAR"}.}
    \item{detcomp}{deterministic components to include in the model. Three types of regressors can be
      included: regular deterministic components, seasonal deterministic components, and any regressor
      variable previously defined by the user.

      This argument must be a list object with the following elements: \code{regular=c(0,0,0)},
      if the first and second element are set equal to 1, it indicates that an intercept, and/or linear trend,
      respectively, are included. The third element in \code{regular} is a vector indicating which seasonal
      dummies should be included. If no seasonal dummies are desired it must be set equal to zero. For
      example, \code{regular=c(1,0,c(1,2,3))} would include an intercept, no trend, and the first three
      seasonal dummies;

      \code{seasonal=c(0,0)}, if an element is set equal to 1, it indicates that seasonal intercepts, and/or
      seasonal trends, respectively, are included in the model;

      \code{regvar=0}, if none regressor variables are considered, this object must be set equal to zero,
      otherwise, the names of a matrix object previously defined should be indicated.}
    \item{p}{the lag order of the model.}
  }

  \details{
    If \code{type} is \code{"AR"} the following model is estimated by ordinary least squares:

    \deqn{y_t = \phi_{1} y_{t-1} + \phi_{2} y_{t-2} + ... + \phi_{p} y_{t-p} + \epsilon_t.}
\cr
    If \code{type} is \code{"PAR"}, the following model is estimated by ordinary least squares:

    \deqn{y_t = \alpha_{1s} y_{t-1} + \alpha_{2s} y_{t-2} + ... + \alpha_{ps} y_{t-p} + \epsilon_t,}

    for \eqn{s=1,...,S}, where \code{S} is the periodicity of the time series.
\cr
    Deterministic components can be added to models above. Be careful when defining the \code{detcomp}
    argument. To include an intercept and seasonal intercepts, or a regular trend with seasonal trends, will
    cause multicollinearity problems.
  }

  \value{
    A \code{fit.partsm-class} class object reporting the estimates of the autoregressive or periodic
    autoregressive coefficients. See \code{\link{fit.partsm-class}} to check further information available
    from this class via the methods \code{show} and \code{summary}.
  }

  \seealso{
    \code{\link{fit.piartsm-class}}, \code{\link{fit.partsm-class}}, and \code{\link{PAR.MVrepr-methods}}.
  }

  \author{Javier Lopez-de-Lacalle \email{javlacalle@yahoo.es}.}

  \references{
    P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).
  }

  \examples{
    ## Models for the the logarithms of the Real GNP in Germany.
    data("gergnp")
    lgergnp <- log(gergnp, base=exp(1))

    ## Fit an AR(4) model with intercept and seasonal dummies.
    detcomp <- list(regular=c(1,0,c(1,2,3)), seasonal=c(0,0), regvar=0)
    out.ar <- fit.ar.par(wts=lgergnp, type="AR", detcomp=detcomp, p=4)

    ## Fit a PAR(2) model with seasonal intercepts.
    detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
    out.par <- fit.ar.par(wts=lgergnp, type="PAR", detcomp=detcomp, p=2)
  }

\keyword{ts}
\keyword{models}

\name{swdipc}
 \docType{data}
  \alias{swdipc}
  \title{Real per Capita Disposable Income in Sweden (1963.1-1988.1)}

  \description{
    Real per capita disposable income in Sweden. Sample: 1963.1 - 1988.1. Remark: measured in logs. This time     series is part of the data set used in the book Franses (1996).
  }

  \format{An object of class 'ts' containing the data.}      

  \usage{
    data ("swdipc")
  }

  \source{Previously available on P.H. Franses's homepage: \url{https://www.eur.nl/en/people/philip-hans-franses}.}

  \references{
    B. Assarson (1991): 'The Stochastic Behaviour of Durables and Nondurables Consumption in Sweden', Working 
    paper 1991:21, Department of Economics, Uppsala University.

    P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).
  }

\keyword{datagen}

\name{show-methods}
 \docType{methods}
  \alias{show-methods}
  \alias{show,ANY-method}
  \alias{show,traceable-method}
  \alias{show,ObjectsWithPackage-method}
  \alias{show,MethodDefinition-method}
  \alias{show,MethodWithNext-method}
  \alias{show,genericFunction-method}
  \alias{show,classRepresentation-method}
  \alias{show,fit.partsm-method}
  \alias{show,fit.piartsm-method}
  \alias{show,Ftest.partsm-method}
  \alias{show,LRur.partsm-method}
  \alias{show,pred.piartsm-method}
  \alias{show,MVPAR-method}
  \alias{show,MVPIAR-method}  

  \title{Methods for Function 'show' in Package 'partsm'}

  \description{
    This method shows the information provided by functions implemented in package 'partsm'.
  }

  \section{Methods}{
    \describe{
      \item{object = "fit.partsm".}{Shows the estimates of the autoregressive or periodic autoregressive
        coefficients.}
      \item{object = "Ftest.partsm".}{Shows the \eqn{F}-test statistic, the null and the alternative
        hypotheses entailed in the procedure, as well as the freedom degrees, the \eqn{p}-value and a symbol
        indicating the significance of the \eqn{F}-statistic according to usual codes, \emph{i.e.} Signif.
        codes: 0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1.}
      \item{object = "fit.piartsm".}{Shows the estimated periodic autoregressive coefficients in the
        restricted non-linear PIAR.}
      \item{object = "LRur.partsm".}{Shows the LR statistics and a one-side test constructed as
        \eqn{sign(g(\hat{\alpha}) - 1) * LR^{1/2}}, where \eqn{g(\hat{\alpha})} is the product of the periodic
        differencing filter parameters estimated under the alternative.}
      \item{object = "pred.piartsm".}{Shows  out-of-sample forecasts and the corresponding standard
        errors, as well as the 95 per cent confidence intervals.}
    }
  }

  \seealso{
    \code{\link{fit.partsm-class}}, \code{\link{Ftest.partsm-class}}, and \code{\link{summary}}.
  }

  \examples{
    ## Load data and select the deterministic components.
    data("gergnp")
    lgergnp <- log(gergnp, base=exp(1))
    detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)

    ## Fit an AR(4) model with intercept and seasonal dummies.
    dcar <- list(regular=c(1,0,c(1,2,3)), seasonal=c(0,0), regvar=0)
    out.ar <- fit.ar.par(wts=lgergnp, type="AR", detcomp=dcar, p=4)
    show(out.ar)

    ## Fit a PAR(2) model with seasonal intercepts.
    out.par <- fit.ar.par(wts=lgergnp, type="PAR", detcomp=detcomp, p=2)
    show(out.par)

    ## Fnextp.test
    Fnextp.out <- Fnextp.test(wts=lgergnp, detcomp=detcomp, p=1, type="PAR")
    show(Fnextp.out)

    ## Fpar.test
    Fpar.out <- Fpar.test(wts=lgergnp, detcomp=detcomp, p=2)
    show(Fpar.out)

    ## Fsh.test
    ar4 <- fit.ar.par(wts=lgergnp, type="AR", p=4, detcomp=detcomp)
    Fsh.out <- Fsh.test(res=residuals(ar4@lm.ar), s=frequency(lgergnp))
    show(Fsh.out)

    ## Fit a PIAR(2) model with seasonal intercepts.
    out.piar <- fit.piar(wts=lgergnp, detcomp=detcomp, p=2)
    show(out.piar)

    ## Fpari.piar.test
    Fpari1.out <- Fpari.piar.test(wts=lgergnp, detcomp=detcomp, p=2, type="PARI1")
    show(Fpari1.out)

    ## Fit a PIAR(2) model with seasonal intercepts.
    out.piar <- fit.piar(wts=lgergnp, detcomp=detcomp, p=2)
    show(out.piar)

    ## Test for a single unit root in a PAR(2) model with seasonal intercepts.
    out.LR <- LRurpar.test(wts=lgergnp, detcomp=detcomp, p=2)
    show(out.LR)

    ## 24 step-ahead forecasts in a PIAR(2) model.
    pred.out <- predictpiar(wts=lgergnp, p=2, hpred=24)
    show(pred.out)
  }

  \author{Javier Lopez-de-Lacalle \email{javlacalle@yahoo.es}.}

\keyword{methods}

\name{fit.piar}
 \alias{fit.piar}
  \title{Fit a Periodically Integrated Autoregressive Model.}

  \description{
    Fit a periodically integrated periodic autoregressive model.
  }

  \usage{
    fit.piar (wts, detcomp, p, initvalues=NULL)
  }

  \arguments{
    \item{wts}{a univariate time series object.}
    \item{detcomp}{a vector indicating the deterministic components included in the auxiliary regression. See
      the corresponding item in \code{\link{fit.ar.par}}.}
    \item{p}{the order of the PAR model. In this version first and second order are considered.}
    \item{initvalues}{by default, initial values are computed for the non-linear model. However, in this
      version there may be cases in which the estimates do not converge, giving an error message. In this
      case, a numeric vector with initial values guessed by the user can be included.}
  }
  
  \details{
    The following equation is estimated by non-linear least squares

    \deqn{ y_t = \alpha_s y_{t-1} + \beta_s (y_{t-1} - \alpha_{s-1} y_{t-2}) + \epsilon_t,}

    under the restriction \eqn{\Pi_{i=1}^{S} \alpha_i = 1} for \eqn{s=1,...,S}, where \eqn{S} denotes
    the number of seasons. Regressors defined in \code{detcomp} can also be included. Obviously, for a first
    order PIAR process \eqn{\beta} parameters are equal to zero.
  }

  \seealso{
    \code{\link[stats]{nls}}, \code{\link{fit.ar.par}}, and \code{\link{fit.piartsm-class}}.
  }

  \value{
    An object of class \code{fit.piartsm-class} containing the estimated coefficients in the restricted
    non-linear model, the residuals, and the periodic autoregressive coefficients. On the basis of the
    estimated \eqn{alpha} parameters, the periodically differenced data are also computed. See
    \code{\link{fit.piartsm-class}} for methods that display this information.
  }

  \author{Javier Lopez-de-Lacalle \email{javlacalle@yahoo.es}.}

  \references{
    P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).
  }

  \examples{
    ## Fit a PIAR(2) model for the logarithms of the Real GNP in Germany.
    data("gergnp")
    lgergnp <- log(gergnp, base=exp(1))
    detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
    out <- fit.piar(wts=lgergnp, detcomp=detcomp, p=2, initvalues=NULL)
  }

\keyword{ts}
\keyword{models}

\name{plotpredpiar}
 \alias{plotpredpiar}
  \title{Plot of the Out-of-Sample Forecasts in a PIAR Model}

  \description{
    This function displays a plot of the predictions and the corresponding 95 per cent confidence intervals
    based on a PIAR model. In this version, this function is implemented for quarterly observed data, PIAR
    models up to order 2 are considered, and seasonal intercepts are included by default.
  }

  \usage{
    plotpredpiar (x)
  }

  \arguments{
    \item{x}{Object of class 'pred.piartsm'.}
  }

  \references{
    P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).    }

  \seealso{
    \code{\link{pred.piartsm-class}}, and \code{\link{predictpiar}}.
  }

  \examples{
    ## Load data and select the deterministic components.
    data("gergnp")
    lgergnp <- log(gergnp, base=exp(1))

    ## Fit a PIAR(2) model with seasonal intercepts.
    out.pred <- predictpiar(wts=lgergnp, p=2, hpred=24)
    plotpredpiar(out.pred)
  }

  \author{Javier Lopez-de-Lacalle \email{javlacalle@yahoo.es}.}

\keyword{hplot}

\name{plotpdiff}
 \alias{plotpdiff}
  \title{Graphical Representation of the Periodically Differenced Data}

  \description{
    On the basis of the estimated parameters in a PIAR model, this function displays the periodically
    differenced data, as well as two different representations of the seasonal paths for the transformed data.
  }

  \usage{
    plotpdiff (x)
  }

  \arguments{
    \item{x}{Object of class 'fir.piartsm'.}
  }

  \references{
    P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).    }

  \seealso{
    \code{\link{fit.piartsm-class}}, and \code{\link{fit.piar}}.
  }

  \examples{
    ## Load data and select the deterministic components.
    data("gergnp")
    lgergnp <- log(gergnp, base=exp(1))
    detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)

    ## Fit a PIAR(2) model with seasonal intercepts.
    out.piar <- fit.piar(wts=lgergnp, detcomp=detcomp, p=2)
    plotpdiff(out.piar)
  }

  \author{Javier Lopez-de-Lacalle \email{javlacalle@yahoo.es}.}

\keyword{hplot}

\name{fit.piartsm}
 \docType{class}
  \alias{fit.piartsm-class}
  \title{fit.piartsm Class}

  \description{
    This class contains information on the periodic autoregressive parameters estimated by
    \code{fit.piar}.
  }

  \section{Slots}{
    \describe{
      \item{\code{p}:}{Object of class \code{"numeric"}: The order of the PIAR model.}
      \item{\code{nls.parameters}:}{Object of class \code{"matrix"}: Estimated coefficients of the
        non-linear PIAR model.}
      \item{\code{nls.res}:}{Object of class \code{"numeric"}: Residuals of the non-linear PIAR model.}
      \item{\code{par.coeffs}:}{Object of class \code{"matrix"}: Periodic autoregressive parameters
        estimates.}
      \item{\code{pdiff.data}:}{Object of class \code{"ts"}: Periodically differenced data.}
    }
  }

  \section{Methods}{
    \describe{
      \item{\code{show}:}{Reports the periodic autoregressive coefficients estimates.}
      \item{\code{summary}:}{Like show, the periodically differenced data are also displayed.}
      \item{\code{plot}:}{Plot the the periodically differenced data, as well as the seasonal paths of the
        transformed data.}
    }
  }

  \references{
    P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).
  }

  \seealso{
    \code{\link{fit.piar}}.
  }

  \author{Javier Lopez-de-Lacalle \email{javlacalle@yahoo.es}.}

\keyword{classes}

\name{MVPIAR-class}
 \docType{class}
  \alias{MVPIAR-class}
  \title{MVPIAR Class}

  \description{This class contains the matrices for the multivariate representation of an object of
    class \code{\link{fit.piartsm-class}}.
  }

  \section{Slots}{
    \describe{
      \item{\code{Phi0}:}{Object of class \code{"matrix"}: Matrix for the multivariate representation. See
        details in \code{\link{PAR.MVrepr-methods}}.}
      \item{\code{Phi1}:}{Object of class \code{"matrix"}: Matrix for the multivariate representation. See
        details in \code{\link{PAR.MVrepr-methods}}.}
      \item{\code{Gamma.eigenvalues}:}{Object of class \code{"numeric"}: Eigenvalues of the matrix
        \eqn{Phi0^{-1} \%*\% Phi1}.}
      \item{\code{tvias}:}{Object of class \code{"matrix"}: Time-varying impact of accumulation of shocks
        calculated as \eqn{Phi0^{-1} \%*\% Phi1 \%*\% Phi0^{-1}}.}
      \item{\code{Omega0}:}{Object of class \code{"ANY"}: Matrix for internal use.}
      \item{\code{Omega1}:}{Object of class \code{"ANY"}: Matrix for internal use.}
      \item{\code{Pi0}:}{Object of class \code{"ANY"}: Matrix for internal use.}
      \item{\code{Pi1}:}{Object of class \code{"ANY"}: Matrix for internal use.}
    }
  }

  \section{Methods}{
    \describe{
      \item{show}{\code{signature(object = "MVPIAR")}: Shows the information contained in the slots.}
    }
  }

  \references{
    P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).
  }

  \author{Javier Lopez-de-Lacalle \email{javlacalle@yahoo.es}.}

  \seealso{
    \code{\link{PAR.MVrepr-methods}}, and \code{\link{fit.piartsm-class}}.
  }

\keyword{classes}

\name{Fnextp.test}
 \alias{Fnextp.test}
  \title{Test for the Significance of the p+1 Autoregressive Parameters in an AR(p) or PAR(p) Model}

  \description{
    Test for the significance of prospective autoregressive parameters of order \eqn{p+1} in an AR(p) or
    PAR(p) model. It is performed as an F-statistic that sets the parameters of order \eqn{p+1} equal to zero.
  }

  \usage{
    Fnextp.test (wts, detcomp, p, type)
  }

  \arguments{
    \item{wts}{a univariate time series object.}
    \item{detcomp}{a vector indicating the deterministic components included in the auxiliary regression.
      See the corresponding item in \code{\link{fit.ar.par}}.}
    \item{p}{the order of the initial AR or PAR model.}
    \item{type}{a character string indicating whether the model to fit is an autoregressive model,
      \code{"AR"}, or a periodic autoregressive model, \code{"PAR"}.}
  }

  \seealso{
    \code{\link{fit.ar.par}}, and \code{\link{Ftest.partsm-class}}.
  }

  \value{
    An object of class \code{\link{Ftest.partsm-class}} containing the \eqn{F}-test statistic, the freedom
    degrees an the corresponding \eqn{p}-value.
  }

  \author{Javier Lopez-de-Lacalle \email{javlacalle@yahoo.es}.}

  \references{
    P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).
  }

  \examples{
    ## Test the significance of a second order lag in a PAR model for the Real GNP in Germany.
    ## Including seasonal intercepts.
    data("gergnp")
    lgergnp <- log(gergnp, base=exp(1))
    detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
    out <- Fnextp.test(wts=lgergnp, detcomp=detcomp, p=1, type="PAR")
  }

\keyword{ts}

\name{ukimp}
 \docType{data}
  \alias{ukimp}
  \title{United Kindom Imports of Goods and Services (1955.1-1988.4)}

  \description{
    United Kindom imports of goods and services. Sample: 1955.1 - 1988.4. Remark: at 1985 prices. This time
    series is part of the data set used in the book Franses (1996).
  }

  \format{An object of class 'ts' containing the data.}


  \usage{
    data ("ukimp")
  }

  \source{Previously available on P.H. Franses's homepage: \url{https://www.eur.nl/en/people/philip-hans-franses}.}

  \references{
    P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).

    D.R. Osborn (1990): A Survey of Seasonality in UK Macroeconomic Variables, \emph{International Journal of
    Forecasting}, \bold{6}, pp. 327-36.    
  }

\keyword{datagen}

\name{usaipisa}
 \docType{data}
  \alias{usaipisa}
  \title{Total Industrial Production Index for the United States (1960.1-1991.4). Seasonally Adjusted}

  \description{
    OECD Main Economic Indicators: Total industrial production index for the United States. Sample: 1960.1 -
    1991.4. Remark: (1985=100), Seasonally Adjusted. This time series is part of the data set used in the
    book Franses (1996).
  }

  \format{An object of class 'ts' containing the data.}  

  \usage{
    data ("usaipisa")
  }

  \source{Previously available on P.H. Franses's homepage: \url{https://www.eur.nl/en/people/philip-hans-franses}.}

  \references{
    P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).
  }

\keyword{datagen}

\name{swndcpc}
 \docType{data}
  \alias{swndcpc}
  \title{Real per Capita non-durables Consumption in Sweden (1963.1 - 1988.1)}

  \description{
    Real per capita non-durables consumption in Sweden. Sample: 1963.1 - 1988.1. Remark: measured in logs.
    This time series is part of the data set used in the book Franses (1996). 
  }

  \format{An object of class 'ts' containing the data.}

  \usage{
    data ("swndcpc")
  }

  \source{Previously available on P.H. Franses's homepage: \url{https://www.eur.nl/en/people/philip-hans-franses}.}

  \references{
    B. Assarson (1991): 'The Stochastic Behaviour of Durables and Nondurables Consumption in Sweden', Working 
    paper 1991:21, Department of Economics, Uppsala University.

    P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).
  }

\keyword{datagen}

\name{Fsh.test}
 \alias{Fsh.test}
  \title{Test for Seasonal Heteroskedasticity}

  \description{
    Test for seasonal heteroskedasticity.
  }

  \usage{
    Fsh.test (res, s)
  }

  \arguments{
    \item{res}{a vector containing the data to be tested.}
    \item{s}{the periodicity of the data.}
  }

  \details{
    On the basis of the following model,

    \deqn{x_t^2 = \omega_0 + \omega_1 D_{1,t} + ... + \omega_{S-1} D_{S-1,t} + \epsilon_t,}

    where \code{S} is the periodicity of the data, the null hypothesis of

    the null-hypothesis \eqn{\omega_{i}=0}, for \eqn{i=1,...,S-1} is tested.

    The F-statistic follows an F((S-1), n-k) distribution, where \code{n} is the number of observations and
    \code{k} the number of parameters.
  }

  \seealso{
    \code{\link{Ftest.partsm-class}}.
  }

  \value{
    An object of class \code{\link{Ftest.partsm-class}} containing the \eqn{F}-test statistic, the freedom
    degrees an the corresponding \eqn{p}-value.
  }

  \author{Javier Lopez-de-Lacalle \email{javlacalle@yahoo.es}.}


  \examples{
    ## Fsh test for the residuals of the first differences
    ## of the logarithms of the Real GNP in Germany
    ## on an AR(4) model with seasonal intercepts.
    data("gergnp")
    lgergnp <- log(gergnp, base=exp(1))
    wts <- ts(c(NA, diff(gergnp, lag=1)), frequency=4, start=start(lgergnp))

    detcomp=list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
    ar4 <- fit.ar.par(wts=lgergnp, type="AR", p=4, detcomp=detcomp)
    out <- Fsh.test(res=residuals(ar4@lm.ar), s=frequency(wts))
  }

\keyword{htest}

\name{fit.partsm}
 \docType{class}
  \alias{fit.partsm-class}
  \title{fit.partsm Class}

  \description{
    This class contains information on the autoregressive or periodic autoregressive parameters estimated by
    \code{\link{fit.ar.par}}.
  }

  \section{Slots}{
    \describe{
      \item{\code{type}:}{Object of class \code{"character"}: The type of the fitted model, an autoregressive
        model, \code{"AR"}, or a periodic autoregressive model, \code{"PAR"}.}
      \item{\code{p}:}{Object of class \code{"numeric"}: The lag order parameter of the model.}
      \item{\code{lm.ar}:}{Object of class \code{"ANY"}: The summary of a fitted AR model. When an AR type
        model is selected, it is of class \code{"lm"}, otherwise the slot is empty.}
      \item{\code{lm.par}:}{Object of class \code{"ANY"}: The summary of a fitted PAR model. When a PAR type
        model is selected, it is of class \code{"lm"}, otherwise the slot is empty.}
      \item{\code{ar.coeffs}:}{Object of class \code{"ANY"}: The autoregressive parameters estimates. When a
        PAR type model is selected, it is of class \code{"matrix"}, otherwise the slot is empty.}
      \item{\code{par.coeffs}:}{Object of class \code{"ANY"}: The periodic autoregressive parameters
        estimates. When a PAR type model is selected, it is of class \code{"matrix"}, otherwise the slot is
        empty.}
    }
  }

  \section{Methods}{
    \describe{
      \item{\code{show}:}{This method reports the autoregressive or periodic autoregressive estimates, 
        depending whether the model is an AR model or a PAR model.}
      \item{\code{summary}:}{In addition to the information reported by \code{show}, a summary of the fitted
        model is also added.}
    }
  }

  \references{
    P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).
  }

  \seealso{
    \code{\link{fit.ar.par}}.
  }

  \author{Javier Lopez-de-Lacalle \email{javlacalle@yahoo.es}.}

\keyword{classes}

\name{pred.piartsm}
 \docType{class}
  \alias{pred.piartsm-class}
  \title{pred.piartsm Class}

  \description{
    This class contains the information provided by \code{\link{predictpiar}}.
  }

  \section{Slots}{
    \describe{
      \item{\code{wts}:}{Object of class \code{"wts"}: The observed time series.}
      \item{\code{hpred}:}{Object of class \code{"numeric"}: The number of forecasts.}
      \item{\code{p}:}{Object of class \code{"numeric"}: The lag order parameter of the PIAR model.}
      \item{\code{fcast}:}{Object of class \code{"ts"}: The out-of-sample forecasts.}
      \item{\code{fse}:}{Object of class \code{"ts"}: The forecast standard errors.}
      \item{\code{ucb}:}{Object of class \code{"ts"}: The upper 95 per cent confidence bound.}
      \item{\code{lcb}:}{Object of class \code{"ts"}: The lower 95 per cent confidence bound.}
    }
  }

  \section{Methods}{
    \describe{
      \item{\code{show}:}{Shows out-of-sample forecasts and the corresponding standard errors, as well as the
        95 per cent confidence intervals.}
    }
  }

  \references{
    P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).
  }

  \seealso{
    \code{\link{predictpiar}}.
  }

  \author{Javier Lopez-de-Lacalle \email{javlacalle@yahoo.es}.}

\keyword{classes}

\name{Fpari.piar.test}
 \alias{Fpari.piar.test}
  \title{Test for a Parameter Restriction in a PAR Model.}

  \description{
    This function performs a test for a parameter restriction in a PAR model. Two restrictions can be
    considered and entail that the process contain either the unit root 1 or the seasonal unit root -1.
    In this version PAR models up to order 2 can be considered.
  }

  \usage{
    Fpari.piar.test (wts, detcomp, p, type)
  }

  \arguments{
    \item{wts}{a univariate time series object.}
    \item{detcomp}{a vector indicating the deterministic components included in the auxiliary regression. See
      the corresponding item in \code{\link{fit.ar.par}}.}
    \item{p}{the order of the initial AR or PAR model. In this version PAR models up to order 2 with seasonal
      intercepts are considered.}
    \item{type}{a character string indicating which restriction should be tested. \code{"PARI1"} indicates that the unit root is tested whereas \code{"PARI-1"} test for the unit root -1.}
  }

  \details{
    On the basis of the following PAR model (in this version PAR models up to order 2 are considered and
    seasonal intercepts are included default),

    \deqn{ y_t = \mu_s + \alpha_s y_{t-1} + \beta_s (y_{t-1} - \alpha_{s-1} y_{t-2}) + \epsilon_t,}

    for \eqn{s=1,...,S}, two different hypotheses can be tested:

    \itemize{
      \item \eqn{H0: \alpha_s = 1, for s=1,...S-1},
      \item \eqn{H0: \alpha_s = -1, for s=1,...S-1}.
    }

    For S=4, if the hypothesis \eqn{\alpha_1*\alpha_2*\alpha_3*\alpha_4=1} cannot be rejected (see
    \link{LRurpar.test}), the null hypotheses above entails that either \eqn{\alpha_4=1} or \eqn{\alpha_4=-1}.

    When the first H0 is not rejected, the PAR model contains the unit root 1, and the periodic difference
    filter is just the first order difference, \eqn{(1-L)}, where \eqn{L} is the lag operator.

    When the second H0 is not rejected, the PAR model contains the unit root -1, and the periodic difference
    filter is simplified as \eqn{(1+L)}.

    In both null hypotheses it is said that the data behave as a PAR model for an integrated series, known as
    PARI. If those null hypotheses are rejected, the corresponding model is called a periodically integrated
    autoregressive model, PIAR.

    The asymptotic distribution of the F-statistic is \eqn{F(S-1, n-k)}, where \eqn{n} is the number of
    observations and \eqn{k} the number of regressors.

    In this version PAR models up to order 2 can be considered.
  }

  \seealso{
    \code{\link{Ftest.partsm-class}}, and \code{\link{LRurpar.test}}.
  }

  \value{
    An object of class \code{\link{Ftest.partsm-class}} containing the \eqn{F}-test statistic, the freedom
    degrees an the corresponding \eqn{p}-value.
  }

  \author{Javier Lopez-de-Lacalle \email{javlacalle@yahoo.es}.}

  \examples{
    ## Test for the unit root 1 in a PAR(2) with seasonal intercepts for
    ## the logarithms of the Real GNP in Germany.
    data("gergnp")
    lgergnp <- log(gergnp, base=exp(1))
    detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
    out <- Fpari.piar.test(wts=lgergnp, detcomp=detcomp, p=2, type="PARI1")
  }

\keyword{htest}

\name{gergnp}
 \docType{data}
  \alias{gergnp}
  \title{Real GNP in Germany (1960.1-1990.4)}

  \description{
    Real GNP in Germany. Sample: 1960.1 - 1990.4. This time series is  part of the data set used in the book
    Franses (1996). 
  }

  \format{An object of class 'ts' containing the data.}

  \usage{
    data ("gergnp")
  }

  \source{Previously available on P.H. Franses's homepage: \url{https://www.eur.nl/en/people/philip-hans-franses}.}

  \references{
    P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).
    
    J. Wolters (1992): Persistence and Seasonality in Output and Employment of the Federal Republic of
    Germany, \emph{Recherches Economiques de Louvain}, \bold{58} pp.421-39.    
  }

\keyword{datagen}

\name{PAR.MVrepr-methods}
 \docType{methods}
  \alias{PAR.MVrepr-methods}
  \alias{PAR.MVrepr,ANY-method}
  \alias{PAR.MVrepr,fit.partsm-method}
  \alias{PAR.MVrepr,fit.piartsm-method}

  \title{Method for Building the Matrices for the Multivariate Representation of a PAR Model}

  \description{
    This method provides the relevant matrices for the multivariate representation of a PAR or PIAR model
    fitted by the functions \code{\link{fit.ar.par}}, and \code{\link{fit.piar}}.
  }

  \section{Methods}{
    \describe{
      \item{object = "fit.partsm".}{Provides a list object containing the estimated matrices \eqn{Phi0},
        \eqn{Phi1}, the eigen values of \eqn{Phi0^{-1} \%*\% Phi1}, and the time-varying impact of accumulation
        of shocks calculated as \eqn{Phi0^{-1} \%*\% Phi1 \%*\% Phi0^{-1}}. See details below.}
      \item{object = "fit.piartsm".}{Provides the same list as in the latter case. See details below.}
    }
  }

  \details{
    In a quarterly time series, the periodic autoregressive model of order \eqn{p} less or equal to 4,

    \deqn{ y_t = \psi_s + \phi_{1s} y_{t-1} + \phi_{2s} y_{t-2} + ... + \phi_{ps} y_{t-p} + \epsilon_t ,}

    with \eqn{s=1,2,3,4}, can be written as a multivariate model as follows,

    \deqn{\Phi_0 y_t = \Psi + \Phi_1 Y_{T-1} + \epsilon_T ,}

    where \eqn{\Phi_0} and \eqn{\Phi_1} are \eqn{S \times S} matrices containing the \eqn{\phi_{is}
    parameters.}

    \eqn{\Phi_0 =}
    \tabular{cccc}{
      \eqn{1}          \tab \eqn{0}          \tab \eqn{0}          \tab \eqn{0} \cr
      \eqn{-\phi_{12}} \tab \eqn{1}          \tab \eqn{0}          \tab \eqn{0} \cr
      \eqn{-\phi_{23}} \tab \eqn{-\phi_{13}} \tab \eqn{1}          \tab \eqn{0} \cr
      \eqn{-\phi_{34}} \tab \eqn{-\phi_{24}} \tab \eqn{-\phi_{14}} \tab \eqn{1} \cr
    }

    \eqn{\Phi_1 =}
      \tabular{cccc}{
      \eqn{\phi_{41}} \tab \eqn{\phi_{31}} \tab \eqn{\phi_{21}} \tab \eqn{\phi_{11}} \cr
      \eqn{0}         \tab \eqn{\phi_{42}} \tab \eqn{\phi_{32}} \tab \eqn{\phi_{22}} \cr
      \eqn{0}         \tab \eqn{0}         \tab \eqn{\phi_{43}} \tab \eqn{\phi_{33}} \cr
      \eqn{0}         \tab \eqn{0}         \tab \eqn{0}         \tab \eqn{\phi_{44}} \cr
    }

    The periodically integrated model of order 2,

    \deqn{ y_t - \alpha_s y_{t-1} = \mu_s + \beta_s (y_{t-1} - \alpha_{s-1} y_{t-2}) + \epsilon_t,}

    with \eqn{s=1,2,3,4}, can be written as a multivariate model as follows,

    \deqn{\Phi_0 y_t = \Psi + \Phi_1 Y_{T-1} + \epsilon_T ,}

    where the matrix \eqn{\Phi_0} and \eqn{\Phi_1} are defined below

    \eqn{\Phi_0 =}
    \tabular{cccc}{
      \eqn{1}         \tab \eqn{0}         \tab \eqn{0}         \tab \eqn{0} \cr
      \eqn{-\alpha_2} \tab \eqn{1}         \tab \eqn{0}         \tab \eqn{0} \cr
      \eqn{0}         \tab \eqn{-\alpha_3} \tab \eqn{1}         \tab \eqn{0} \cr
      \eqn{0}         \tab \eqn{0}         \tab \eqn{-\alpha_4} \tab \eqn{1} \cr
    }

    \eqn{\Phi_1 =}
    \tabular{cccc}{
      \eqn{0} \tab \eqn{0} \tab \eqn{0} \tab \eqn{\alpha_1} \cr
      \eqn{0} \tab \eqn{0} \tab \eqn{0} \tab \eqn{0} \cr
      \eqn{0} \tab \eqn{0} \tab \eqn{0} \tab \eqn{0} \cr
      \eqn{0} \tab \eqn{0} \tab \eqn{0} \tab \eqn{0} \cr
    }

    The \eqn{\Phi_0} and \eqn{\Phi_1} matrices can be used to compute the impact of accumulation of the
    shocks \eqn{\epsilon_t}. The impact matrix is defined as \eqn{\Gamma \Phi_0^{-1}}, where \eqn{\Gamma} is
    \eqn{\Phi_0^{-1} \Phi_0}.

    That row in which the values of the impact matrix are the highest, entails that the corresponding season
    undergoes more severe impacts from the accumulation of all shocks. Hence, it is more likely to display
    fluctuations in the stochastic trend. Put in other words, the impact matrix allow the practitioner to get
    an idea about how the stochastic trend and the seasonal fluctuations are related.

  }

  \seealso{
    \code{\link{fit.partsm-class}}, and \code{\link{fit.piartsm-class}}.
  }

  \examples{
    ## Load data and select the deterministic components.
    data("gergnp")
    lgergnp <- log(gergnp, base=exp(1))
    detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)

    ## Multivariate representation of a PAR(2) model with sesonal intercepts.
    out.par <- fit.ar.par(wts=lgergnp, type="PAR", detcomp=detcomp, p=2)
    PAR.MVrepr(out.par)

    ## Multivariate representation of a PIAR(2) model with sesonal intercepts.
    out.piar <- fit.piar(wts=lgergnp, detcomp=detcomp, p=2)
    PAR.MVrepr(out.piar)
  }

  \author{Javier Lopez-de-Lacalle \email{javlacalle@yahoo.es}.}

\keyword{methods}

\name{PAR.MVrepr }
 \alias{PAR.MVrepr }
  \title{Multivariate representation of a PAR model}

  \description{
    The function \code{PAR.MVrepr} applied on the \code{out.par} object of class \code{fit.partsm}, shows
 the multivariate representation as well as some complementary information of a PAR process.
  }

  \usage{
    PAR.MVrepr(object)
  }

  \arguments{
    \item{object}{An object of class \code{fit.partsm} or \code{fit.piartsm}}
  }

  \details{
    For more information, see the vignette, section 2.
  }

  \value{
    A list with different objects
  }


  \author{Javier Lopez-de-Lacalle \email{javlacalle@yahoo.es}.}

  \references{
    P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).
  }

  \examples{
    ## Models for the the logarithms of the Real GNP in Germany.
    data("gergnp")
    lgergnp <- log(gergnp, base=exp(1))

    ## Fit an PAR model
    detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
    out.par <- fit.ar.par(wts=lgergnp, type="PAR", detcomp=detcomp, p=2)

    ## Show the matrix representation: 
    out.MV <- PAR.MVrepr(out.par)
    out.MV
  }

\keyword{ts}

\name{predictpiar}
 \alias{predictpiar}
  \title{Predictions for a Restricted Periodic Autoregressive Model}

  \description{
    This function performs predictions for a restricted periodic autoregressive model. This version
    considers PIAR models up to order 2 with seasonal intercepts. It is implemented for quarterly observed data.
  }

  \usage{
    predictpiar (wts, p, hpred)
  }

  \arguments{
    \item{wts}{a univariate time series object.}
    \item{p}{the order of the PAR model. At present first and second order are considered.}
    \item{hpred}{number of out-of-sample observations to forecast. It must be a multiple of 4.}
  }

  \details{
    Upon the multivariate representation,

    \deqn{\Phi_0 y_t = \Psi + \Phi_1 Y_{T-1} + ... + \Phi_P y_{T-P} + \epsilon_T ,}

    where the \eqn{\Phi_i, i=1,2,...,P} are \eqn{s \times s} matrices containing the \eqn{\phi_{is}
    parameters.}, the one-step-ahead forecasts for the year \eqn{T+1} is straightforward,

    \deqn{ y_t = \Phi_0^{-1} \Psi + \Phi_0^{-1} \Phi_1 Y_{T-1} + ... + \Phi_0^{-1} \Phi_P y_{T-P} +
    \Phi_0^{-1} + \epsilon_T .}

    Multi-step-ahead forecasts are obtained recursively.

    The prediction errors variances for the one-step-ahead forecast are the diagonal elements of

    \deqn{ \sigma^2 \Phi_0^{-1} (\Phi_0^{-1})^{'}, }

    whereas for \eqn{h=2,3,...} years ahead forecasts it becomes

    \deqn{\sigma^2 \Phi_0^{-1} (\Phi_0^{-1})^{'} + (h-1) (\Gamma \Phi_0^{-1}) (\Gamma \Phi_0^{-1})^{'},}

    where \eqn{\Gamma = \Phi_0^{-1} \Phi_1}.

    This version considers PIAR models up to order 2 for quarterly observed data. By default, seasonal
    intercepts are included in the model as deterministic components.

    The number of observations to forecast, \code{hpred} must be a multiple of 4.
  }

  \seealso{
    \code{\link{fit.piar}}, \code{\link{PAR.MVrepr-methods}}, and \code{\link{pred.piartsm-class}}.
  }

  \value{
    An object of class \code{\link{pred.piartsm-class}} containing the forecasts and the corresponding
    standard errors, as well as the 95 per cent confidence intervals.
  }

  \author{Javier Lopez-de-Lacalle \email{javlacalle@yahoo.es}.}

  \references{
    P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).
  }

  \examples{
    ## 24 step-ahead forecasts in a PIAR(2) model for the
    ## logarithms of the Real GNP in Germany.
    data("gergnp")
    lgergnp <- log(gergnp, base=exp(1))
    pred.out <- predictpiar(wts=lgergnp, p=2, hpred=24)
  }

\keyword{models}
\keyword{ts}

\name{acf.ext1}
 \alias{acf.ext1}
  \title{Autocorrelation function for several transformations of the original data}

  \description{
     This function is based on the \link[stats]{acf} function and extends it by allowing for some transformations of the data before computing the autocovariance or autocorrelation function.
   }

   \usage{
      acf.ext1 (wts, transf.type, perdiff.coeffs, type, lag.max, showcat, plot)
   }

   \arguments{
      \item{wts}{a univariate time series object.
      }
      \item{transf.type}{a character string indicating what transformation should be applied to the data. Allowed values are "orig", "fdiff", "sdiff", "fsdiff", "fdiffsd", "perdiff", and ""perdiffsd. See details.
      }
      \item{perdiff.coeffs}{a vector with the estimates coefficients for the periodic difference filter. This argument is only required when the periodic difference transformation must be applied to the data. See details.
      }
      \item{type}{a character string giving the type of acf to be computed. Allowed values are "correlation",
"covariance" or "partial".
      }
      \item{lag.max}{maximum number of lags at which to calculate the acf.
      }
      \item{showcat}{a logical. If TRUE, the results are printed in detail. If FALSE, the results are stored as a list object.
      }
      \item{plot}{a logical. If TRUE, a plot of the acf is showed.
      }
   }

   \details{The implemented transformations are the following:
     \itemize{
      \item "orig": Original series.
      \item "fdiff": First differences of the original series.
      \item "sdiff": Seasonal differences of the original series.
      \item "fsdiff": Fisrt and seasonal differences of the original series.
      \item "fdiffsd": Residuals of the first differences on four seasonal dummy variables.
      \item "perdiff": Periodic differences of the original series.
      \item "perdiffsd": Residuals of the periodic differences on four seasonal dummy variables.
     }
   }

   \seealso{
      \code{\link[stats]{acf}}.
   }

   \value{
     Lags at which the acf is computed, estimates of the acf, and p-values for the significance of the acf at each lag.
   }

   \author{Javier Lopez-de-Lacalle \email{javlacalle@yahoo.es}.}

   \examples{
      ## Logarithms of the Real GNP in Germany
      data("gergnp")
      lgergnp <- log(gergnp, base=exp(1))

      out <- acf.ext1(wts=lgergnp, transf.type="orig",
                      type="correlation", lag.max=12, showcat=TRUE, plot=FALSE)

      out <- acf.ext1(wts=lgergnp, transf.type="perdiffsd", 
                      perdiff.coeff = c(1.004, 0.981, 1.047, 0.969),
                      type="correlation", lag.max=12, showcat=TRUE, plot=FALSE)
   }
   \keyword{misc}

\name{canunsa}
 \docType{data}
  \alias{canunsa}
  \title{Unemployment in Canada. (1960.1-1987.4). Seasonally Adjusted}

  \description{
    OECD Main Economic Indicators: Unemployment in Canada. Sample: 1960.1 - 1987.4. Remark: Seasonally
    Adjusted. This time series is part of the data set used in the book Franses (1996).
  }

  \format{An object of class 'ts' containing the data.}

  \usage{
    data ("canunsa")
  }

  \source{Previously available on P.H. Franses's homepage: \url{https://www.eur.nl/en/people/philip-hans-franses}.}

  \references{
    P.H. Franses: Periodicity and Stochastic Trends in Economic Time canunsas (Oxford University Press, 1996).
  }

\keyword{datagen}

\name{LRurpar.test}
 \alias{LRurpar.test}
  \title{Likelihood Ratio Test for a Single Unit Root in a PAR(p) Model}

  \description{
    This function performs the likelihood ratio test for a single unit root in a PAR(p) model up to order 2.
  }

  \usage{
    LRurpar.test (wts, detcomp, p)
  }

  \arguments{
    \item{wts}{a univariate time series object.}
    \item{detcomp}{a vector indicating the deterministic components included in the auxiliary regression. See
      the corresponding item in \code{\link{fit.ar.par}}.}
    \item{p}{the order of the PAR model. In this version first and second order models are considered.}
  }

  \details{
    In a quarterly time series, the PAR(1) model, \eqn{y_t = \alpha_{s,1} y_{t-1} + \epsilon_t} with
    \eqn{\epsilon_t ID(0,1)}, contains a unit root if \eqn{g(\alpha) = \Pi_{s=1}^4 \alpha_{s,1} = 1}. To test
    this hypothesis, a likelihood ratio test, \code{LR}, is built as the logarithm of the ratio between the
    residual sum of squares in the unrestricted and the restricted model, weighted by the number of
    observations.

    The unrestricted PAR model is estimated by OLS, whereas the model in which the null hypothesis is
    imposed, \emph{i.e.} \eqn{\Pi_{s=1}^4 \alpha_{s,1} = 1}, is estimated by nonlinear least squares.

    The critical values are reported in Osterwald-Lenum (1992), table 1.1 (for the case where \eqn{p-r=1}).

    In this version, PAR models up to order 2 with seasonal intercepts are considered, since the function
    \code{\link{fit.piar}} does not allow for higher orders.
  }

  \seealso{
    \code{\link{fit.ar.par}}, \code{\link{fit.piar}}, and \code{\link{LRur.partsm-class}}.
  }

  \value{
    An object of class \code{\link{LRur.partsm-class}} containing the LR statistics and a one-side test
    constructed as \eqn{sign(g(\hat{\alpha}) - 1) * LR^{1/2}}, where \eqn{g(\hat{\alpha})} is the product of
    the periodic differencing filter parameters estimated under the alternative.
  }

  \author{Javier Lopez-de-Lacalle \email{javlacalle@yahoo.es}.}

  \references{
    H.P. Boswijk and P.H. Franses (1996), Unit roots in periodic autoregressions. \emph{Journal of Time
    series Analysis}, \bold{17}, pp. 221-245.

    P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).

    Osterwald-Lenum, M. (1992), A Note with Quantiles of the Asymptotic Distribution of the Maximum
    Likelihood Cointegration Rank Test Statistics: Four Cases. \emph{Oxford Bulletin of Economics and
    Statistics}, \bold{54}, pp.461-472.
  }

  \examples{
    ## Test for a single unit root in a PAR(2) model with seasonal intercepts for the
    ## logarithms of the Real GNP in Germany.
    data("gergnp")
    lgergnp <- log(gergnp, base=exp(1))
    detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
    out <- LRurpar.test(wts=lgergnp, detcomp=detcomp, p=2)
  }

\keyword{htest}

\name{Ftest.partsm}
 \docType{class}
  \alias{Ftest.partsm-class}
  \title{Ftest.partsm Class}

  \description{
    This class contains the information provided by the \eqn{F}-tests available in the package
    \code{'partsm'}.
  }

  \section{Slots}{
    \describe{
      \item{\code{test.label}:}{Object of class \code{"character"}: A label to identify the test that the
        information is related to.}
      \item{\code{test.name}:}{Object of class \code{"character"}: A one-line description of the test.}
      \item{\code{p}:}{Object of class \code{"numeric"}: The order of the AR or PAR model.}
      \item{\code{Fstat}:}{Object of class \code{"numeric"}: The \eqn{F}-statistic.}
      \item{\code{df}:}{Object of class \code{"numeric"}: The freedom degrees.}
      \item{\code{pval}:}{Object of class \code{"numeric"}: The \eqn{p}-value.}
      \item{\code{pvl}:}{Object of class \code{"character"}: A symbol indicating the significance of the
        \eqn{F}-statistic according to usual codes, \emph{i.e.} Signif. codes: 0 '***' 0.001 '**' 0.01 '*'
        0.05 '.' 0.1 ' ' 1.}
      \item{\code{h0md}:}{Object of class \code{"lm"}: The summary of the model fitted for the null
        hypothesis.}
      \item{\code{hamd}:}{Object of class \code{"ANY"}:  The summary of the model fitted for the
        alternative hypothesis.}
    }
  }

  \section{Methods}{
    \describe{
      \item{\code{show}:}{This method reports the \eqn{F}-test statistic, the null and the alternative
        hypotheses entailed in the procedure, as well as the freedom degrees, the \eqn{p}-value and the
        codified \eqn{p}-value.}
      \item{\code{summary}:}{In addition to the information reported by \code{show}, a summary of the fitted
        models for the null and the alternative hypotheses is also added.}
    }
  }

  \references{
    P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).
  }

  \seealso{
    \code{\link{Fnextp.test}}, \code{\link{Fpar.test}}, \code{\link{Fsh.test}}, and
    \code{\link{Fpari.piar.test}}.
  }

  \author{Javier Lopez-de-Lacalle \email{javlacalle@yahoo.es}.}

\keyword{classes}

\name{LRur.partsm}
 \docType{class}
  \alias{LRur.partsm-class}

  \title{LRur.partsm Class}

  \description{
    This class contains the information provided by \code{\link{LRurpar.test}}.
  }

  \section{Slots}{
    \describe{
      \item{\code{test.label}:}{Object of class \code{"character"}: A label to identify the test.}
      \item{\code{test.name}:}{Object of class \code{"character"}: A one-line description of the test.}
      \item{\code{p}:}{Object of class \code{"numeric"}: The lag order parameter of the model.}
      \item{\code{LR}:}{Object of class \code{"numeric"}: The LR statistic.}
      \item{\code{LRtau}:}{Object of class \code{"numeric"}: The one side test statistic.}
      \item{\code{h0nls}:}{Object of class \code{"matrix"}: The estimated coefficients of the non-linear PIAR
        model.}
      \item{\code{halm}:}{Object of class \code{"lm"}: The estimated PAR model for the alternative
        hypotheses.}
    }
  }

  \section{Methods}{
    \describe{
      \item{\code{show}:}{Shows the LR statistics and a one-side test constructed as
        \eqn{sign(g(\hat{\alpha}) - 1) * LR^{1/2}}, where \eqn{g(\hat{\alpha})} is the product of the periodic
        differencing filter parameters estimated under the alternative.}
      \item{\code{summary}:}{Displays the same output as \code{show} but a summary of the null and the
        alternative hypotheses is also displayed.}
    }
  }

  \references{
    P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).
  }

  \seealso{
    \code{\link{LRurpar.test}}.
  }

  \author{Javier Lopez-de-Lacalle \email{javlacalle@yahoo.es}.}

\keyword{classes}

\name{Fpar.test}
 \alias{Fpar.test}
  \title{Test for Periodic Variation in the Autoregressive Parameters}

  \description{
    Test for periodic variation in the autoregressive parameters.
  }

  \usage{
    Fpar.test (wts, detcomp, p)
  }

  \arguments{
    \item{wts}{a univariate time series object.}
    \item{detcomp}{a vector indicating the deterministic components included in the auxiliary regression. See
      the corresponding item in \code{\link{fit.ar.par}}.}
    \item{p}{the order of the initial AR or PAR model.}
  }

  \details{
    An F-test based on the residual sum of squares is performed to test for periodic variation in the
    autoregressive parameters.

    On the basis of the following model,

    \deqn{y_t = \phi_{1s} y_{t-1} + ... + \phi_{ps} y_{t-p} + \epsilon_t,}

    for \eqn{s=1,...,S}, where \code{S} is the periodicity of the time series,

    the null-hypothesis is non-periodicity: \eqn{\phi_{is}=\phi_i}, for \eqn{s=1,...,S} and
    \eqn{i=1,2,...,p}. When the null hypothesis is imposed an AR(p) is estimated, whereas the alternative is
    a PAR(p) model.

    The F-statistic when four seasonal intercepts are included follows an F((S-1)*p, n-(S+S*p)) distribution,      where \code{S} is the periodicity of the series and \code{n} the number of observations.
  }

  \seealso{
    \code{\link{fit.ar.par}}, and \code{\link{Ftest.partsm-class}}.
  }

  \value{
    An object of class \code{\link{Ftest.partsm-class}} containing the \eqn{F}-test statistic, the freedom
    degrees an the corresponding \eqn{p}-value.
  }

  \author{Javier Lopez-de-Lacalle \email{javlacalle@yahoo.es}.}

  \examples{
    ## Test for periodicity in a second order PAR model for
    ## the logarithms of the Real GNP in Germany time series.
    data("gergnp")
    lgergnp <- log(gergnp, base=exp(1))
    detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
    out <- Fpar.test(wts=lgergnp, detcomp=detcomp, p=2)
  }

\keyword{htest}
